# SPDX-FileCopyrightText: 2014-2018 Tony DiCola, Limor Fried, Brennen Bearnes
#
# SPDX-License-Identifier: MIT

"""
Attempt to detect the current platform.
"""
import os
import re
import sys

try:
    from typing import Optional
except ImportError:
    pass

from adafruit_platformdetect.board import Board
from adafruit_platformdetect.chip import Chip

# Needed to find libs (like libusb) installed by homebrew on Apple Silicon
if sys.platform == "darwin":
    os.environ["DYLD_FALLBACK_LIBRARY_PATH"] = "/opt/homebrew/lib/"


# Various methods here may retain state in future, so tell pylint not to worry
# that they don't use self right now:
# pylint: disable=no-self-use
class Detector:
    """Wrap various platform detection functions."""

    def __init__(self) -> None:
        self.board = Board(self)
        self.chip = Chip(self)

    def get_cpuinfo_field(self, field: str) -> Optional[str]:
        """
        Search /proc/cpuinfo for a field and return its value, if found,
        otherwise None.
        """
        # Match a line like 'Hardware   : BCM2709':
        pattern = r"^" + field + r"\s+:\s+(.*)$"

        with open("/proc/cpuinfo", "r", encoding="utf-8") as infile:
            cpuinfo = infile.read().split("\n")
        for line in cpuinfo:
            match = re.search(pattern, line, flags=re.IGNORECASE)
            if match:
                return match.group(1)
        return None

    def check_dt_compatible_value(self, value: str) -> bool:
        """
        Search /proc/device-tree/compatible for a value and return True, if found,
        otherwise False.
        """
        # Match a value like 'qcom,apq8016-sbc':
        dt_compatible = self.get_device_compatible()
        if dt_compatible and value in dt_compatible:
            return True

        return False

    def get_armbian_release_field(self, field: str) -> Optional[str]:
        """
        Search /etc/armbian-release, if it exists, for a field and return its
        value, if found, otherwise None.
        """
        field_value = None

        pattern = r"^" + field + r"=(.*)"
        try:
            with open("/etc/armbian-release", "r", encoding="utf-8") as release_file:
                armbian = release_file.read().split("\n")
                for line in armbian:
                    match = re.search(pattern, line)
                    if match:
                        field_value = match.group(1)
        except FileNotFoundError:
            pass

        return field_value

    def get_device_model(self) -> Optional[str]:
        """
        Search /proc/device-tree/model for the device model and return its value, if found,
        otherwise None.
        """
        try:
            with open("/proc/device-tree/model", "r", encoding="utf-8") as model_file:
                return model_file.read()
        except FileNotFoundError:
            pass
        return None

    def get_device_compatible(self) -> Optional[str]:
        """
        Search /proc/device-tree/compatible for the compatible chip name.
        """
        try:
            with open(
                "/proc/device-tree/compatible", "r", encoding="utf-8"
            ) as model_file:
                return model_file.read()
        except FileNotFoundError:
            pass
        return None

    def check_board_asset_tag_value(self) -> Optional[str]:
        """
        Search /sys/devices/virtual/dmi/id for the device model and return its value, if found,
        otherwise None.
        """
        try:
            with open(
                "/sys/devices/virtual/dmi/id/board_asset_tag", "r", encoding="utf-8"
            ) as tag_file:
                return tag_file.read().strip()
        except FileNotFoundError:
            pass
        return None

    def check_board_name_value(self) -> Optional[str]:
        """
        Search /sys/devices/virtual/dmi/id for the board name and return its value, if found,
        otherwise None. Debian/ubuntu based
        """
        try:
            with open(
                "/sys/devices/virtual/dmi/id/board_name", "r", encoding="utf-8"
            ) as board_name_file:
                return board_name_file.read().strip()
        except FileNotFoundError:
            pass
        return None



# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""
`adafruit_platformdetect.chip`
================================================================================

Attempt detection of current chip / CPU

* Author(s): Melissa LeBlanc-Williams

Implementation Notes
--------------------

**Software and Dependencies:**

* Linux and Python 3.7 or Higher

"""

import os
import sys

try:
    from typing import Optional
except ImportError:
    pass

from adafruit_platformdetect.constants import chips

__version__ = "3.85.0"
__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PlatformDetect.git"


class Chip:
    """Attempt detection of current chip / CPU."""

    def __init__(self, detector) -> None:
        self.detector = detector
        self._chip_id = None

    # pylint: disable=invalid-name,too-many-branches,too-many-return-statements
    @property
    def id(
        self,
    ) -> Optional[str]:
        """Return a unique id for the detected chip, if any."""
        # There are some times we want to trick the platform detection
        # say if a raspberry pi doesn't have the right ID, or for testing

        # Caching
        if self._chip_id:
            return self._chip_id

        if getattr(os, "environ", None) is not None:
            try:
                return os.environ["BLINKA_FORCECHIP"]
            except KeyError:  # no forced chip, continue with testing!
                pass

            # Special cases controlled by environment var
            if os.environ.get("BLINKA_FT232H"):
                from pyftdi.usbtools import UsbTools

                # look for it based on PID/VID
                count = len(UsbTools.find_all([(0x0403, 0x6014)]))
                if count == 0:
                    raise RuntimeError(
                        "BLINKA_FT232H environment variable "
                        + "set, but no FT232H device found"
                    )
                self._chip_id = chips.FT232H
                return self._chip_id
            if os.environ.get("BLINKA_FT2232H"):
                from pyftdi.usbtools import UsbTools

                # look for it based on PID/VID
                count = len(UsbTools.find_all([(0x0403, 0x6010)]))
                if count == 0:
                    raise RuntimeError(
                        "BLINKA_FT2232H environment variable "
                        + "set, but no FT2232H device found"
                    )
                self._chip_id = chips.FT2232H
                return self._chip_id
            if os.environ.get("BLINKA_FT4232H"):
                from pyftdi.usbtools import UsbTools

                # look for it based on PID/VID
                count = len(UsbTools.find_all([(0x0403, 0x6011)]))
                if count == 0:
                    raise RuntimeError(
                        "BLINKA_FT4232H environment variable "
                        + "set, but no FT4232H device found"
                    )
                self._chip_id = chips.FT4232H
                return self._chip_id
            if os.environ.get("BLINKA_MCP2221"):
                import hid

                # look for it based on PID/VID
                for dev in hid.enumerate():
                    if dev["vendor_id"] == 0x04D8 and dev["product_id"] == 0x00DD:
                        self._chip_id = chips.MCP2221
                        return self._chip_id
                raise RuntimeError(
                    "BLINKA_MCP2221 environment variable "
                    + "set, but no MCP2221 device found"
                )
            if os.environ.get("BLINKA_SPIDRIVER"):
                self._chip_id = chips.SPIDRIVER
                return self._chip_id
            if os.environ.get("BLINKA_OS_AGNOSTIC"):
                # we don't need to look for this chip, it's just a flag
                self._chip_id = chips.OS_AGNOSTIC
                return self._chip_id
            if os.environ.get("BLINKA_U2IF"):
                import hid

                # look for it based on PID/VID
                for dev in hid.enumerate():
                    vendor = dev["vendor_id"]
                    product = dev["product_id"]
                    # NOTE: If any products are added here, they need added
                    # to _rp2040_u2if_id() in board.py as well.
                    # pylint: disable=too-many-boolean-expressions
                    if (
                        (
                            # Raspberry Pi Pico
                            # Radxa X4
                            vendor in (0xCAFE, 0xCAFF)
                            and product == 0x4005
                        )
                        or (
                            # Waveshare RP2040 One
                            vendor == 0x2E8A
                            and product == 0x103A
                        )
                        or (
                            # Feather RP2040
                            # Itsy Bitsy RP2040
                            # QT Py RP2040
                            # QT2040 Trinkey
                            # MacroPad RP2040
                            # Feather RP2040 ThinkInk
                            # Feather RP2040 RFM
                            # Feather RP2040 CAN Bus
                            vendor == 0x239A
                            and product
                            in (
                                0x00F1,
                                0x00FD,
                                0x00F7,
                                0x0109,
                                0x0107,
                                0x812C,
                                0x812E,
                                0x8130,
                                0x0105,
                            )
                        )
                    ):
                        self._chip_id = chips.RP2040_U2IF
                        return self._chip_id
                raise RuntimeError(
                    "BLINKA_U2IF environment variable "
                    + "set, but no compatible device found"
                )
            if os.environ.get("BLINKA_GREATFET"):
                import usb

                if usb.core.find(idVendor=0x1D50, idProduct=0x60E6) is not None:
                    self._chip_id = chips.LPC4330
                    return self._chip_id
                raise RuntimeError(
                    "BLINKA_GREATFET environment variable "
                    + "set, but no GreatFET device found"
                )
            if os.environ.get("BLINKA_NOVA"):
                self._chip_id = chips.BINHO
                return self._chip_id

        platform = sys.platform
        if platform in ("linux", "linux2"):
            self._chip_id = self._linux_id()
            return self._chip_id
        if platform == "esp8266":
            self._chip_id = chips.ESP8266
            return self._chip_id
        if platform == "samd21":
            self._chip_id = chips.SAMD21
            return self._chip_id
        if platform == "pyboard":
            self._chip_id = chips.STM32F405
            return self._chip_id
        if platform == "rp2":
            self._chip_id = chips.RP2040
            return self._chip_id
        # nothing found!
        return None

    # pylint: enable=invalid-name

    def _linux_id(self) -> Optional[str]:
        # pylint: disable=too-many-branches,too-many-statements
        # pylint: disable=too-many-return-statements
        """Attempt to detect the CPU on a computer running the Linux kernel."""
        if self.detector.check_dt_compatible_value("beagle,am67a-beagley-ai"):
            return chips.AM67A
        if self.detector.check_dt_compatible_value("ti,am625"):
            return chips.AM625X
        if self.detector.check_dt_compatible_value("ti,am654"):
            return chips.AM65XX

        if self.detector.check_dt_compatible_value("ti,am652"):
            return chips.AM65XX

        if self.detector.check_dt_compatible_value("sun4i-a10"):
            return chips.A10

        if self.detector.check_dt_compatible_value("sun7i-a20"):
            return chips.A20

        if self.detector.check_dt_compatible_value("amlogic,g12a"):
            return chips.S905Y2
        if self.detector.check_dt_compatible_value("amlogic, g12a"):
            return chips.S905X3

        if self.detector.check_dt_compatible_value("sun8i-h3"):
            return chips.H3

        if self.detector.check_dt_compatible_value("qcom,apq8016"):
            return chips.APQ8016

        if self.detector.check_dt_compatible_value("fu500"):
            return chips.HFU540

        if self.detector.check_dt_compatible_value("sun20iw1p1"):
            return chips.C906

        # Older Builds
        if self.detector.check_dt_compatible_value("sifive"):
            return chips.JH71X0

        # Newer Builds
        if self.detector.check_dt_compatible_value("jh7100"):
            return chips.JH71X0

        if self.detector.check_dt_compatible_value("jh7110"):
            return chips.JH7110

        if self.detector.check_dt_compatible_value("sun8i-a33"):
            return chips.A33

        if self.detector.check_dt_compatible_value("rockchip,rk3308"):
            return chips.RK3308

        if self.detector.check_dt_compatible_value("radxa,rock-4c-plus"):
            return chips.RK3399_T

        if self.detector.check_dt_compatible_value("rockchip,rk3399pro"):
            return chips.RK3399PRO

        if self.detector.check_dt_compatible_value("rockchip,rk3399"):
            return chips.RK3399

        if self.detector.check_dt_compatible_value("rockchip,rk3288"):
            return chips.RK3288

        if self.detector.check_dt_compatible_value("rockchip,rk3328"):
            return chips.RK3328

        if self.detector.check_dt_compatible_value("rockchip,rk3566"):
            return chips.RK3566

        if self.detector.check_dt_compatible_value("rockchip,rk3568"):
            return chips.RK3568

        if self.detector.check_dt_compatible_value("rockchip,rk3588s"):
            return chips.RK3588S

        if self.detector.check_dt_compatible_value("rockchip,rk3588"):
            return chips.RK3588

        if self.detector.check_dt_compatible_value("rockchip,rv1106"):
            return chips.RV1106

        if self.detector.check_dt_compatible_value("rockchip,rv1103"):
            return chips.RV1103

        if self.detector.check_dt_compatible_value("amlogic,a311d"):
            return chips.A311D

        if self.detector.check_dt_compatible_value("st,stm32mp157"):
            return chips.STM32MP157

        if self.detector.check_dt_compatible_value("st,stm32mp153"):
            return chips.STM32MP157DAA1

        if self.detector.check_dt_compatible_value("sun50i-a64"):
            return chips.A64

        if self.detector.check_dt_compatible_value("sun50i-h5"):
            return chips.H5

        if self.detector.check_dt_compatible_value("sun50i-h618"):
            return chips.H618

        if self.detector.check_dt_compatible_value("sun50i-h616"):
            return chips.H616

        if self.detector.check_dt_compatible_value("sun50iw9"):
            return chips.H616

        if self.detector.check_dt_compatible_value("sun50i-h6"):
            return chips.H6

        if self.detector.check_dt_compatible_value("sun55iw3"):
            return chips.T527

        if self.detector.check_dt_compatible_value("spacemit,k1-x"):
            return chips.K1

        if self.detector.check_dt_compatible_value("renesas,r9a09g056"):
            return chips.RZV2N

        if self.detector.check_dt_compatible_value("renesas,r9a09g057"):
            return chips.RZV2H

        if self.detector.check_dt_compatible_value("mediatek,mt8167"):
            return chips.MT8167

        if self.detector.check_dt_compatible_value("imx6ull"):
            return chips.IMX6ULL

        if self.detector.check_dt_compatible_value("ti,j721e"):
            return chips.TDA4VM

        if self.detector.check_dt_compatible_value("sun20i-d1"):
            return chips.D1_RISCV

        if self.detector.check_dt_compatible_value("imx8mp"):
            return chips.IMX8MP

        if self.detector.check_dt_compatible_value("libretech,aml-s905x-cc"):
            return chips.S905X

        if self.detector.check_dt_compatible_value("light-lpi4a"):
            return chips.TH1520

        if self.detector.check_dt_compatible_value("hobot,x3"):
            return chips.SUNRISE_X3

        if self.detector.check_dt_compatible_value("Horizon, x5"):
            return chips.SUNRISE_X5

        if self.detector.check_dt_compatible_value("particle,tachyon"):
            return chips.QCM6490

        linux_id = None
        hardware = self.detector.get_cpuinfo_field("Hardware")

        if hardware is None:
            vendor_id = self.detector.get_cpuinfo_field("vendor_id")
            if vendor_id == "AuthenticAMD":
                model_name = self.detector.get_cpuinfo_field("model name").upper()
                if "RYZEN EMBEDDED V1202B" in model_name:
                    linux_id = chips.RYZEN_V1202B
                if "RYZEN EMBEDDED V1605B" in model_name:
                    linux_id = chips.RYZEN_V1605B
                else:
                    linux_id = chips.GENERIC_X86
            ##            print("linux_id = ", linux_id)
            elif vendor_id == "GenuineIntel":
                model_name = self.detector.get_cpuinfo_field("model name").upper()
                ##                print('model_name =', model_name)
                if "N3710" in model_name:
                    linux_id = chips.PENTIUM_N3710
                if "N5105" in model_name:
                    linux_id = chips.CELERON_N5105
                elif "X5-Z8350" in model_name:
                    linux_id = chips.ATOM_X5_Z8350
                elif "J4105" in model_name:
                    linux_id = chips.ATOM_J4105
                else:
                    linux_id = chips.GENERIC_X86
            ##            print("linux_id = ", linux_id)

            compatible = self.detector.get_device_compatible()
            if compatible and "tegra" in compatible:
                compats = compatible.split("\x00")
                if "nvidia,tegra210" in compats:
                    linux_id = chips.T210
                elif "nvidia,tegra186" in compats:
                    linux_id = chips.T186
                elif "nvidia,tegra194" in compats:
                    linux_id = chips.T194
                elif "nvidia,tegra234" in compats:
                    linux_id = chips.T234
                elif "nvidia,tegra264" in compats:
                    linux_id = chips.T264
            if compatible and "imx8m" in compatible:
                linux_id = chips.IMX8MX
            if compatible and "odroid-c2" in compatible:
                linux_id = chips.S905
            if compatible and "amlogic" in compatible:
                compatible_list = (
                    compatible.replace("\x00", ",").replace(" ", "").split(",")
                )
                if "g12a" in compatible_list:
                    # 'sm1' is correct for S905X3, but some kernels use 'g12a'
                    return chips.S905X3
                if "g12b" in compatible_list:
                    return chips.S922X
                if "sm1" in compatible_list:
                    return chips.S905X3
                if "vim3amlogic" in compatible_list:
                    return chips.A311D
            if compatible and "sun50i-a64" in compatible:
                linux_id = chips.A64
            if compatible and "sun50i-h6" in compatible:
                linux_id = chips.H6
            if compatible and "sun50i-h5" in compatible:
                linux_id = chips.H5
            if compatible and "odroid-xu4" in compatible:
                linux_id = chips.EXYNOS5422
            if compatible and "cvitek,cv180x" in compatible:
                linux_id = chips.CV1800B
            if compatible and "xlnx,zynqmp" in compatible:
                linux_id = chips.ZYNQMP
            cpu_model = self.detector.get_cpuinfo_field("cpu model")

            if cpu_model is not None:
                if "MIPS 24Kc" in cpu_model:
                    linux_id = chips.MIPS24KC
                elif "MIPS 24KEc" in cpu_model:
                    linux_id = chips.MIPS24KEC

            # we still haven't identified the hardware, so
            # convert it to a list and let the remaining
            # conditions attempt.
            if not linux_id:
                hardware = [
                    entry.replace("\x00", "") for entry in compatible.split(",")
                ]

        if not linux_id:
            if "AM33XX" in hardware:
                linux_id = chips.AM33XX
            elif "DRA74X" in hardware:
                linux_id = chips.DRA74X
            elif "sun4i" in hardware:
                linux_id = chips.A10
            elif "sun7i" in hardware:
                linux_id = chips.A20
            elif "sun8i" in hardware:
                linux_id = chips.SUN8I
            elif "ODROIDC" in hardware:
                linux_id = chips.S805
            elif "ODROID-C2" in hardware:
                linux_id = chips.S905
            elif "ODROID-N2" in hardware:
                linux_id = chips.S922X
            elif "ODROID-C4" in hardware:
                linux_id = chips.S905X3
            elif "ODROID-XU4" in hardware:
                linux_id = chips.EXYNOS5422
            elif "KHADAS-VIM3" in hardware:
                linux_id = chips.A311D
            elif "SAMA5" in hardware:
                linux_id = chips.SAMA5
            elif "Pinebook" in hardware:
                linux_id = chips.A64
            elif "ASUS_TINKER_BOARD" in hardware:
                linux_id = chips.RK3288
            elif "Xilinx Zynq" in hardware:
                compatible = self.detector.get_device_compatible()
                if compatible and "xlnx,zynq-7000" in compatible:
                    linux_id = chips.ZYNQ7000
            else:
                if isinstance(hardware, str):
                    if hardware.upper() in chips.BCM_RANGE:
                        linux_id = chips.BCM2XXX
                elif isinstance(hardware, list):
                    if {model.upper() for model in hardware} & chips.BCM_RANGE:
                        linux_id = chips.BCM2XXX

        return linux_id

    def __getattr__(self, attr: str) -> bool:
        """
        Detect whether the given attribute is the currently-detected chip.  See
        list of constants at the top of this module for available options.
        """
        if attr == "id":
            raise AttributeError()  # Avoid infinite recursion
        if self.id == attr:
            return True
        return False



#!/usr/bin/env python3

# SPDX-FileCopyrightText: 2023 Melissa LeBlanc-Williams for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""
`bin.rpi_info`
================================================================================

Interactive mode will prompt for the revision code
Otherwise it will be detected automatically

* Author(s): Melissa LeBlanc-Williams

Implementation Notes
--------------------

**Software and Dependencies:**

* Linux and Python 3.7 or Higher

"""

import sys
import argparse
import adafruit_platformdetect
from adafruit_platformdetect.revcodes import PiDecoder

detector = adafruit_platformdetect.Detector()
parser = argparse.ArgumentParser()


def print_property(label, value):
    """Format and print a property"""
    print(f"{label}: {value}")


def main(interactive):
    """Run the program"""
    pi_rev_code = detector.board._pi_rev_code()  # pylint: disable=protected-access

    if pi_rev_code is None:
        print("Raspberry Pi not detected. Using interactive mode")

    if pi_rev_code is None or interactive:
        pi_rev_code = input(
            "Enter a Raspberry Pi revision code (e.g. d03114 or 000f): "
        )

    print_property("Revision Code", pi_rev_code)

    try:
        decoder = PiDecoder(pi_rev_code)
    except ValueError:
        print("Invalid revision code. It should be a hexadecimal value.")
        sys.exit(1)

    if not decoder.is_valid_code():
        print(
            "Code is invalid. This rev code includes at least one "
            "value that is outside of the expected range."
        )
        sys.exit(1)

    if decoder.is_new_format():
        print_property("Overvoltage", decoder.overvoltage)
        print_property("OTP Program", decoder.otp_program)
        print_property("OTP Read", decoder.otp_read)
        print_property("Warranty bit", decoder.warranty_bit)
        print_property("New flag", decoder.rev_style)
        print_property("Memory size", decoder.memory_size)
        print_property("Manufacturer", decoder.manufacturer)
        print_property("Processor", decoder.processor)
        print_property("Type", decoder.type)
        print_property("Revision", decoder.revision)
    else:
        print_property("Warranty bit", decoder.warranty_bit)
        print_property("Model", decoder.type)
        print_property("Revision", decoder.revision)
        print_property("RAM", decoder.memory_size)
        print_property("Manufacturer", decoder.manufacturer)


# Main function
if __name__ == "__main__":
    parser.add_argument(
        "-i", "--interactive", help="Interactive Mode", action="store_true"
    )
    args = parser.parse_args()
    main(args.interactive)



# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""Definition of boards and/or ids"""
# Allow for aligned constant definitions:
VISIONFIVE2 = "VISIONFIVE2"
BEAGLE_PLAY = "BEAGLE_PLAY"
BEAGLEBONE_AI64 = "BEAGLEBONE_AI64"
BEAGLEBONE = "BEAGLEBONE"
BEAGLEBONE_BLACK = "BEAGLEBONE_BLACK"
BEAGLEBONE_BLUE = "BEAGLEBONE_BLUE"
BEAGLEBONE_BLACK_WIRELESS = "BEAGLEBONE_BLACK_WIRELESS"
BEAGLEBONE_POCKETBEAGLE = "BEAGLEBONE_POCKETBEAGLE"
BEAGLEBONE_GREEN = "BEAGLEBONE_GREEN"
BEAGLEBONE_GREEN_WIRELESS = "BEAGLEBONE_GREEN_WIRELESS"
BEAGLEBONE_GREEN_GATEWAY = "BEAGLEBONE_GREEN_GATEWAY"
BEAGLEBONE_BLACK_INDUSTRIAL = "BEAGLEBONE_BLACK_INDUSTRIAL"
BEAGLEBONE_ENHANCED = "BEAGLEBONE_ENHANCED"
BEAGLEBONE_USOMIQ = "BEAGLEBONE_USOMIQ"
BEAGLEBONE_AIR = "BEAGLEBONE_AIR"
BEAGLEBONE_AI = "BEAGLEBONE_AI"
BEAGLEBONE_POCKETBONE = "BEAGLEBONE_POCKETBONE"
BEAGLEV_STARLIGHT = "BEAGLEV_STARLIGHT"
BEAGLEY_AI = "BEAGLEY_AI"
BEAGLELOGIC_STANDALONE = "BEAGLELOGIC_STANDALONE"
OSD3358_DEV_BOARD = "OSD3358_DEV_BOARD"
OSD3358_SM_RED = "OSD3358_SM_RED"
OLIMEX_LIME2 = "OLIMEX_LIME2"
FEATHER_HUZZAH = "FEATHER_HUZZAH"
FEATHER_M0_EXPRESS = "FEATHER_M0_EXPRESS"
GENERIC_LINUX_PC = "GENERIC_LINUX_PC"
PYBOARD = "PYBOARD"
NODEMCU = "NODEMCU"
RASPBERRY_PI_PICO = "RASPBERRY_PI_PICO"
GIANT_BOARD = "GIANT_BOARD"

# ASUS Tinker Boards
ASUS_TINKER_BOARD = "ASUS_TINKER_BOARD"
ASUS_TINKER_BOARD_2 = "ASUS_TINKER_BOARD_2"
ASUS_TINKER_EDGE_R = "ASUS_TINKER_EDGE_R"

# Walnut Pi boards
WALNUT_PI_1B = "WALNUT_PI_1B"
WALNUT_PI_1B_EMMC = "WALNUT_PI_1B_EMMC"

# Clockwork Pi boards
CLOCKWORK_CPI3 = "CLOCKWORK_CPI3"

# Orange Pi boards
ORANGE_PI_PC = "ORANGE_PI_PC"
ORANGE_PI_R1 = "ORANGE_PI_R1"
ORANGE_PI_ZERO = "ORANGE_PI_ZERO"
ORANGE_PI_ONE = "ORANGE_PI_ONE"
ORANGE_PI_LITE = "ORANGE_PI_LITE"
ORANGE_PI_PC_PLUS = "ORANGE_PI_PC_PLUS"
ORANGE_PI_PLUS_2E = "ORANGE_PI_PLUS_2E"
ORANGE_PI_2 = "ORANGE_PI_2"
ORANGE_PI_PC2 = "ORANGE_PI_PC2"
ORANGE_PI_ZERO_PLUS_2H5 = "ORANGE_PI_ZERO_PLUS_2H5"
ORANGE_PI_ZERO_PLUS = "ORANGE_PI_ZERO_PLUS"
ORANGE_PI_ZERO_2 = "ORANGE_PI_ZERO_2"
ORANGE_PI_ZERO_3 = "ORANGE_PI_ZERO_3"
ORANGE_PI_3 = "ORANGE_PI_3"
ORANGE_PI_3B = "ORANGE_PI_3B"
ORANGE_PI_3_LTS = "ORANGE_PI_3_LTS"
ORANGE_PI_4 = "ORANGE_PI_4"
ORANGE_PI_4_LTS = "ORANGE_PI_4_LTS"
ORANGE_PI_5 = "ORANGE_PI_5"
ORANGE_PI_5_MAX = "ORANGE_PI_5_MAX"
ORANGE_PI_5_PLUS = "ORANGE_PI_5_PLUS"
ORANGE_PI_5_PRO = "ORANGE_PI_5_PRO"

# Nano Pi boards
NANOPI_NEO_AIR = "NANOPI_NEO_AIR"
NANOPI_DUO2 = "NANOPI_DUO2"
NANOPI_NEO = "NANOPI_NEO"
NANOPI_NEO_2 = "NANOPI_NEO_2"

# Banana Pi boards
BANANA_PI_M2_ZERO = "BANANA_PI_M2_ZERO"
BANANA_PI_M2_PLUS = "BANANA_PI_M2_PLUS"
BANANA_PI_M2_BERRY = "BANANA_PI_M2_BERRY"
BANANA_PI_M4_BERRY = "BANANA_PI_M4_BERRY"
BANANA_PI_M4_ZERO = "BANANA_PI_M4_ZERO"
BANANA_PI_M5 = "BANANA_PI_M5"
BANANA_PI_F3 = "BANANA_PI_F3"
BANANA_PI_F5 = "BANANA_PI_F5"
BANANA_PI_AI2N = "BANANA_PI_AI2N"
BANANA_PI_AI2H = "BANANA_PI_AI2H"

# LeMaker boards
LEMAKER_BANANA_PRO = "LEMAKER_BANANA_PRO"

# NVIDIA Jetson boards
JETSON_TX1 = "JETSON_TX1"
JETSON_TX2 = "JETSON_TX2"
JETSON_TX2_NX = "JETSON_TX2_NX"
CLARA_AGX_XAVIER = "CLARA_AGX_XAVIER"
JETSON_XAVIER = "JETSON_XAVIER"
JETSON_AGX_ORIN = "JETSON_ORIN"
JETSON_NANO = "JETSON_NANO"
JETSON_NX = "JETSON_NX"
JETSON_ORIN_NANO = "JETSON_ORIN_NANO"
JETSON_ORIN_NX = "JETSON_ORIN_NX"
JETSON_THOR = "JETSON_THOR"

# Texas Instruments SK boards
TI_J721E_SK = "TI_J721E_SK"

# Google Coral dev board
CORAL_EDGE_TPU_DEV = "CORAL_EDGE_TPU_DEV"
CORAL_EDGE_TPU_DEV_MINI = "CORAL_EDGE_TPU_DEV_MINI"

# Xilinx PYNQ FPGA dev boards
PYNQ_Z1 = "PYNQ_Z1"
PYNQ_Z2 = "PYNQ_Z2"

# STM32 MPU boards
STM32MP157C_DK2 = "STM32MP157C_DK2"
OSD32MP1_BRK = "OSD32MP1_BRK"
OSD32MP1_RED = "OSD32MP1_RED"
STMP157_OLINUXINO_LIME2 = "STMP157_OLINUXINO_LIME2"

# Embedfire LubanCat board
LUBANCAT_IMX6ULL = "LUBANCAT_IMX6ULL"
LUBANCAT_STM32MP157 = "LUBANCAT_STM32MP157"
LUBANCAT_ZERO = "LUBANCAT_ZERO"
LUBANCAT1 = "LUBANCAT1"
LUBANCAT2 = "LUBANCAT2"
LUBANCAT4 = "LUBANCAT4"
LUBANCAT5 = "LUBANCAT5"

# Various Raspberry Pi models
RASPBERRY_PI_B_REV1 = "RASPBERRY_PI_B_REV1"
RASPBERRY_PI_B_REV2 = "RASPBERRY_PI_B_REV2"
RASPBERRY_PI_B_PLUS = "RASPBERRY_PI_B_PLUS"
RASPBERRY_PI_A = "RASPBERRY_PI_A"
RASPBERRY_PI_A_PLUS = "RASPBERRY_PI_A_PLUS"
RASPBERRY_PI_CM1 = "RASPBERRY_PI_CM1"
RASPBERRY_PI_ZERO = "RASPBERRY_PI_ZERO"
RASPBERRY_PI_ZERO_W = "RASPBERRY_PI_ZERO_W"
RASPBERRY_PI_ZERO_2_W = "RASPBERRY_PI_ZERO_2_W"
RASPBERRY_PI_2B = "RASPBERRY_PI_2B"
RASPBERRY_PI_3B = "RASPBERRY_PI_3B"
RASPBERRY_PI_3B_PLUS = "RASPBERRY_PI_3B_PLUS"
RASPBERRY_PI_CM3 = "RASPBERRY_PI_CM3"
RASPBERRY_PI_3A_PLUS = "RASPBERRY_PI_3A_PLUS"
RASPBERRY_PI_CM3_PLUS = "RASPBERRY_PI_CM3_PLUS"
RASPBERRY_PI_4B = "RASPBERRY_PI_4B"
RASPBERRY_PI_AVNET_IIOT_GW = "RASPBERY_PI_AVNET_IIOT_GW"
RASPBERRY_PI_400 = "RASPBERRY_PI_400"
RASPBERRY_PI_CM4 = "RASPBERRY_PI_CM4"
RASPBERRY_PI_CM4S = "RASPBERRY_PI_CM4S"
RASPBERRY_PI_5 = "RASPBERRY_PI_5"
RASPBERRY_PI_CM5 = "RASPBERRY_PI_CM5"
RASPBERRY_PI_500 = "RASPBERRY_PI_500"
RASPBERRY_PI_CM5_LITE = "RASPBERRY_PI_CM5_LITE"

ODROID_C1 = "ODROID_C1"
ODROID_C1_PLUS = "ODROID_C1_PLUS"
ODROID_C2 = "ODROID_C2"
ODROID_C4 = "ODROID_C4"
ODROID_H3 = "ODROID_H3"
ODROID_N2 = "ODROID_N2"
ODROID_XU4 = "ODROID_XU4"
ODROID_M1 = "ODROID_M1"
ODROID_M1S = "ODROID_M1S"

FTDI_FT232H = "FTDI_FT232H"
FTDI_FT2232H = "FTDI_FT2232H"
FTDI_FT4232H = "FTDI_FT4232H"
DRAGONBOARD_410C = "DRAGONBOARD_410C"

EXCAMERA_SPIDRIVER = "EXCAMERA_SPIDRIVER"
EXCAMERA_I2CDRIVER = "EXCAMERA_I2CDRIVER"

SIFIVE_UNLEASHED = "SIFIVE_UNLEASHED"

ALLWINER_D1 = "ALLWINER_D1"
LICHEE_RV = "LICHEE_RV"
LICHEEPI_4A = "LICHEEPI_4A"

MICROCHIP_MCP2221 = "MICROCHIP_MCP2221"

# Linkspirte Pcduino based boards
PCDUINO2 = "PCDUINO2"
PCDUINO3 = "PCDUINO3"

# Boards with u2if firmware
# https://github.com/execuc/u2if
PICO_U2IF = "PICO_U2IF"
FEATHER_U2IF = "FEATHER_U2IF"
FEATHER_CAN_U2IF = "FEATHER_CAN_U2IF"
FEATHER_EPD_U2IF = "FEATHER_EPD_U2IF"
FEATHER_RFM_U2IF = "FEATHER_RFM_U2IF"
ITSYBITSY_U2IF = "ITSYBITSY_U2IF"
MACROPAD_U2IF = "MACROPAD_U2IF"
QTPY_U2IF = "QTPY_U2IF"
QT2040_TRINKEY_U2IF = "QT2040_TRINKEY_U2IF"
KB2040_U2IF = "KB2040_U2IF"

RP2040_ONE_U2IF = "RP2040_ONE_U2IF"
RADXA_X4_U2IF = "RADXA_X4_U2IF"

BINHO_NOVA = "BINHO_NOVA"

ONION_OMEGA = "ONION_OMEGA"
ONION_OMEGA2 = "ONION_OMEGA2"

PINE64 = "PINE64"
PINEH64 = "PINEH64"
PINEBOOK = "PINEBOOK"
PINEPHONE = "PINEPHONE"
SOPINE = "SOPINE"
QUARTZ64_A = "QUARTZ64_A"

RADXA_ZERO = "RADXA_ZERO"
RADXA_ZERO3 = "RADXA_ZERO3"
RADXA_CM3 = "RADXA_CM3"

ROCK_PI_3A = "ROCK_PI_3A"
ROCK_3B = "ROCK_3B"
ROCK_PI_3C = "ROCK_PI_3C"
ROCK_PI_S = "ROCK_PI_S"
ROCK_PI_4 = "ROCK_PI_4"
ROCK_PI_4_C_PLUS = "ROCK_PI_4C+"
ROCK_PI_4_SE = "ROCK_PI_4_SE"
ROCK_PI_X = "ROCK_PI_X"
ROCK_PI_E = "ROCK_PI_E"
ROCK_PI_5 = "ROCK_PI_5"
ROCK_PI_5C = "ROCK_PI_5C"

# Vicharak Boards
VAAMAN = "VAAMAN"
AXON = "AXON"

GREATFET_ONE = "GREATFET_ONE"

# SeeedStudio boards
ODYSSEY_X86J41X5 = "ODYSSEY_X86J41X5"

# Udoo boards
UDOO_BOLT_V3 = "UDOO_BOLT_V3"
UDOO_BOLT_V8 = "UDOO_BOLT_V8"
UDOO_X86 = "UDOO_X86"

# MaaXBoard
MAAXBOARD = "MAAXBOARD"
MAAXBOARD_MINI = "MAAXBOARD_MINI"

# Shenzhen MilkV Technology boards ids
MILKV_DUO = "MILKV_DUO"

# Khadas VIM3
KHADAS_VIM3 = "KHADAS_VIM3"

_KHADAS_40_PIN_IDS = (KHADAS_VIM3,)

# Vivid Unit
VIVID_UNIT = "VIVID_UNIT"

_VIVID_UNIT_IDS = (VIVID_UNIT,)

# Luckfox Pico boards
LUCKFOX_PICO = "LUCKFOX_PICO"
LUCKFOX_PICO_MAX = "LUCKFOX_PICO_MAX"
LUCKFOX_PICO_ULTRA = "LUCKFOX_PICO_ULTRA"
LUCKFOX_PICO_MINI = "LUCKFOX_PICO_MINI"
LUCKFOX_PICO_PLUS = "LUCKFOX_PICO_PLUS"

# Ameridroid boards
INDIEDROID_NOVA = "INDIEDROID_NOVA"

# Horizon
RDK_X3 = "RDK_X3"
RDK_X5 = "RDK_X5"

# Particle
PARTICLE_TACHYON = "PARTICLE_TACHYON"

# StarFive boards
_STARFIVE_BOARD_IDS = (VISIONFIVE2,)
# Asus Tinkerboard
_ASUS_TINKER_BOARD_IDS = (
    ASUS_TINKER_BOARD,
    ASUS_TINKER_BOARD_2,
    ASUS_TINKER_EDGE_R,
)

# WalnutPi
_WALNUT_PI_IDS = (
    WALNUT_PI_1B,
    WALNUT_PI_1B_EMMC,
)

# STM32MP1
_STM32MP1_IDS = (
    STM32MP157C_DK2,
    LUBANCAT_STM32MP157,
    OSD32MP1_BRK,
    OSD32MP1_RED,
    STMP157_OLINUXINO_LIME2,
)

# OrangePI
_ORANGE_PI_IDS = (
    ORANGE_PI_PC,
    ORANGE_PI_R1,
    ORANGE_PI_ZERO,
    ORANGE_PI_ONE,
    ORANGE_PI_LITE,
    ORANGE_PI_PC_PLUS,
    ORANGE_PI_PLUS_2E,
    ORANGE_PI_2,
    ORANGE_PI_PC2,
    ORANGE_PI_ZERO_PLUS_2H5,
    ORANGE_PI_ZERO_PLUS,
    ORANGE_PI_ZERO_2,
    ORANGE_PI_3,
    ORANGE_PI_3B,
    ORANGE_PI_3_LTS,
    ORANGE_PI_4,
    ORANGE_PI_4_LTS,
    ORANGE_PI_5,
    ORANGE_PI_5_PLUS,
    ORANGE_PI_5_PRO,
)

# NanoPi
_NANOPI_IDS = (
    NANOPI_NEO_AIR,
    NANOPI_DUO2,
    NANOPI_NEO,
    NANOPI_NEO_2,
)

# BananaPI
_BANANA_PI_IDS = (
    BANANA_PI_M2_ZERO,
    BANANA_PI_M2_PLUS,
    BANANA_PI_M2_BERRY,
    BANANA_PI_M4_BERRY,
    BANANA_PI_M4_ZERO,
    BANANA_PI_M5,
    BANANA_PI_F3,
    BANANA_PI_F5,
    BANANA_PI_AI2N,
    BANANA_PI_AI2H,
)

# LeMaker
_LEMAKER_IDS = (LEMAKER_BANANA_PRO,)

# LubanCat
_LUBANCAT_IDS = (
    LUBANCAT_IMX6ULL,
    LUBANCAT_STM32MP157,
    LUBANCAT_ZERO,
    LUBANCAT1,
    LUBANCAT2,
    LUBANCAT4,
    LUBANCAT5,
)

# Coral boards
_CORAL_IDS = (CORAL_EDGE_TPU_DEV, CORAL_EDGE_TPU_DEV_MINI)

_PYNQ_IDS = (PYNQ_Z1, PYNQ_Z2)

_JETSON_IDS = (
    (JETSON_TX1, ("nvidia,p2371-2180", "nvidia,jetson-cv")),
    (
        JETSON_TX2,
        (
            "nvidia,p2771-0000",
            "nvidia,p2771-0888",
            "nvidia,p3489-0000",
            "nvidia,lightning",
            "nvidia,quill",
            "nvidia,storm",
        ),
    ),
    (JETSON_TX2_NX, ("nvidia,p3509-0000+p3636-0001",)),
    (CLARA_AGX_XAVIER, ("nvidia,e3900-0000+p2888-0004",)),
    (
        JETSON_XAVIER,
        (
            "nvidia,p2972-0000",
            "nvidia,p2972-0006",
            "nvidia,jetson-xavier",
            "nvidia,jetson-xavier-industrial",
            "nvidia,galen-industrial",
        ),
    ),
    (JETSON_NANO, ("nvidia,p3450-0000", "nvidia,p3450-0002", "nvidia,jetson-nano")),
    (
        JETSON_NX,
        (
            "nvidia,p3509-0000+p3668-0000",
            "nvidia,p3509-0000+p3668-0001",
            "nvidia,p3509-0000-a00+p3668-0000-a01",
            "nvidia,p3509-0000-a00+p3668-0001-a01",
            "nvidia,p3449-0000+p3668-0000",
            "nvidia,p3449-0000+p3668-0001",
            "nvidia,p3449-0000+p3668-0003",
        ),
    ),
    (
        JETSON_AGX_ORIN,
        (
            "nvidia,p3737-0000+p3701-0000",
            "nvidia,p3737-0000+p3701-0004",
            "nvidia,p3737-0000+p3701-0008",
            "nvidia,p3737-0000+p3701-0005",
            "nvidia,p3737-0000+p3701-0001",
        ),
    ),
    (
        JETSON_ORIN_NX,
        (
            "nvidia,p3509-0000+p3767-0000",
            "nvidia,p3768-0000+p3767-0000",
            "nvidia,p3509-0000+p3767-0001",
            "nvidia,p3768-0000+p3767-0001",
            "nvidia,p3768-0000+p3767-0000-super",
            "nvidia,p3768-0000+p3767-0001-super",
        ),
    ),
    (
        JETSON_ORIN_NANO,
        (
            "nvidia,p3509-0000+p3767-0003",
            "nvidia,p3768-0000+p3767-0003",
            "nvidia,p3768-0000+p3767-0003-super",
            "nvidia,p3509-0000+p3767-0004",
            "nvidia,p3768-0000+p3767-0004",
            "nvidia,p3509-0000+p3767-0005",
            "nvidia,p3768-0000+p3767-0005",
            "nvidia,p3768-0000+p3767-0005-super",
            "nvidia,p3768-0000+p3767-0003-super",
            "nvidia,p3768-0000+p3767-0004-super",
        ),
    ),
    (
        JETSON_THOR,
        (
            "nvidia,p3971-0050+p3834-0005",
            "nvidia,p3971-0080+p3834-0008",
            "nvidia,p3971-0089+p3834-0008",
            "nvidia,p4071-0000+p3834-0008",
        ),
    ),
)

_TI_SK_BOARD_IDS = ((TI_J721E_SK, ("ti,j721e-sk", "ti,j721e")),)

# Raspberry Pi boards

_RASPBERRY_PI_40_PIN_IDS = (
    RASPBERRY_PI_B_PLUS,
    RASPBERRY_PI_A_PLUS,
    RASPBERRY_PI_ZERO,
    RASPBERRY_PI_ZERO_W,
    RASPBERRY_PI_ZERO_2_W,
    RASPBERRY_PI_2B,
    RASPBERRY_PI_3B,
    RASPBERRY_PI_3B_PLUS,
    RASPBERRY_PI_3A_PLUS,
    RASPBERRY_PI_4B,
    RASPBERRY_PI_AVNET_IIOT_GW,
    RASPBERRY_PI_400,
    RASPBERRY_PI_5,
    RASPBERRY_PI_500,
)

_RASPBERRY_PI_CM_IDS = (
    RASPBERRY_PI_CM1,
    RASPBERRY_PI_CM3,
    RASPBERRY_PI_CM3_PLUS,
    RASPBERRY_PI_CM4,
    RASPBERRY_PI_CM4S,
    RASPBERRY_PI_CM5,
    RASPBERRY_PI_CM5_LITE,
)

# Pi 4 boards have additional peripherals
_RASPBERRY_PI_4_IDS = (
    RASPBERRY_PI_4B,
    RASPBERRY_PI_CM4,
    RASPBERRY_PI_CM4S,
    RASPBERRY_PI_400,
)

# Pi 5 boards work differently
_RASPBERRY_PI_5_IDS = (
    RASPBERRY_PI_5,
    RASPBERRY_PI_CM5,
    RASPBERRY_PI_500,
    RASPBERRY_PI_CM5_LITE,
)

_PI_MODELS = {
    0x00: RASPBERRY_PI_A,
    0x01: {
        1.0: RASPBERRY_PI_B_REV1,
        2.0: RASPBERRY_PI_B_REV2,
    },
    0x02: RASPBERRY_PI_A_PLUS,
    0x03: RASPBERRY_PI_B_PLUS,
    0x04: RASPBERRY_PI_2B,
    0x06: RASPBERRY_PI_CM1,
    0x08: RASPBERRY_PI_3B,
    0x09: RASPBERRY_PI_ZERO,
    0x0A: RASPBERRY_PI_CM3,
    0x0B: RASPBERRY_PI_AVNET_IIOT_GW,
    0x0C: RASPBERRY_PI_ZERO_W,
    0x0D: RASPBERRY_PI_3B_PLUS,
    0x0E: RASPBERRY_PI_3A_PLUS,
    0x10: RASPBERRY_PI_CM3_PLUS,
    0x11: RASPBERRY_PI_4B,
    0x12: RASPBERRY_PI_ZERO_2_W,
    0x13: RASPBERRY_PI_400,
    0x14: RASPBERRY_PI_CM4,
    0x15: RASPBERRY_PI_CM4S,
    0x17: RASPBERRY_PI_5,
    0x18: RASPBERRY_PI_CM5,
    0x19: RASPBERRY_PI_500,
    0x1A: RASPBERRY_PI_CM5_LITE,
}

# ODROID boards

_ODROID_40_PIN_IDS = (
    ODROID_C1,
    ODROID_C1_PLUS,
    ODROID_C2,
    ODROID_C4,
    ODROID_N2,
    ODROID_XU4,
    ODROID_M1,
    ODROID_M1S,
)

_ODROID_MINI_PC_IDS = (ODROID_H3,)

_BEAGLEBONE_IDS = (
    BEAGLEY_AI,
    BEAGLE_PLAY,
    BEAGLEBONE_AI64,
    BEAGLEBONE,
    BEAGLEBONE_BLACK,
    BEAGLEBONE_BLUE,
    BEAGLEBONE_BLACK_WIRELESS,
    BEAGLEBONE_POCKETBEAGLE,
    BEAGLEBONE_GREEN,
    BEAGLEBONE_GREEN_WIRELESS,
    BEAGLEBONE_GREEN_GATEWAY,
    BEAGLEBONE_BLACK_INDUSTRIAL,
    BEAGLEBONE_ENHANCED,
    BEAGLEBONE_USOMIQ,
    BEAGLEBONE_AIR,
    BEAGLEBONE_AI,
    BEAGLEBONE_POCKETBONE,
    BEAGLELOGIC_STANDALONE,
    BEAGLEV_STARLIGHT,
    OSD3358_DEV_BOARD,
    OSD3358_SM_RED,
)

_LINARO_96BOARDS_IDS = (DRAGONBOARD_410C,)

_SIFIVE_IDS = (SIFIVE_UNLEASHED,)

_OLIMEX_IDS = (OLIMEX_LIME2,)

# BeagleBone eeprom board ids from:
#   https://github.com/beagleboard/image-builder
# Thanks to zmatt on freenode #beagle for pointers.
_BEAGLEBONE_BOARD_IDS = {
    BEAGLE_PLAY: ("A0", "7.BEAGLE"),
    BEAGLEBONE_AI64: ("B0", "7.BBONEA"),
    # Original bone/white:
    BEAGLEBONE: (
        ("A3", "A335BONE00A3"),
        ("A4", "A335BONE00A4"),
        ("A5", "A335BONE00A5"),
        ("A6", "A335BONE00A6"),
        ("A6A", "A335BONE0A6A"),
        ("A6B", "A335BONE0A6B"),
        ("B", "A335BONE000B"),
    ),
    BEAGLEBONE_BLACK: (
        ("A5", "A335BNLT00A5"),
        ("A5A", "A335BNLT0A5A"),
        ("A5B", "A335BNLT0A5B"),
        ("A5C", "A335BNLT0A5C"),
        ("A6", "A335BNLT00A6"),
        ("A6A", "A335BNLT0A6A"),
        ("B", "A335BNLT000B"),
        ("C", "A335BNLT000C"),
        ("C", "A335BNLT00C0"),
        ("D", "A335BNLT00D0"),
    ),
    BEAGLEBONE_BLUE: (("A2", "A335BNLTBLA2"),),
    BEAGLEBONE_BLACK_WIRELESS: (("A5", "A335BNLTBWA5"),),
    BEAGLEBONE_POCKETBEAGLE: (("A2", "A335PBGL00A2"),),
    BEAGLEBONE_GREEN: (("1A", "A335BNLT...."), ("UNKNOWN", "A335BNLTBBG1")),
    BEAGLEBONE_GREEN_WIRELESS: (("W1A", "A335BNLTGW1A"),),
    BEAGLEBONE_GREEN_GATEWAY: (("GA1", "A335BNLTGG1A"),),
    BEAGLEBONE_BLACK_INDUSTRIAL: (
        ("A0", "A335BNLTAIA0"),  # Arrow
        ("A0", "A335BNLTEIA0"),  # Element14
    ),
    BEAGLEBONE_ENHANCED: (("A", "A335BNLTSE0A"),),
    BEAGLEBONE_USOMIQ: (("6", "A335BNLTME06"),),
    BEAGLEBONE_AIR: (("A0", "A335BNLTNAD0"),),
    BEAGLEBONE_POCKETBONE: (("0", "A335BNLTBP00"),),
    OSD3358_DEV_BOARD: (("0.1", "A335BNLTGH01"),),
    OSD3358_SM_RED: (("0", "A335BNLTOS00"),),
    BEAGLELOGIC_STANDALONE: (("A", "A335BLGC000A"),),
}

# Onion omega boards
_ONION_OMEGA_BOARD_IDS = (ONION_OMEGA, ONION_OMEGA2)

# Pine64 boards and devices
_PINE64_DEV_IDS = (PINE64, PINEH64, PINEBOOK, PINEPHONE, SOPINE, QUARTZ64_A)

# Pcduino boards
_PCDUINO_DEV_IDS = (PCDUINO2, PCDUINO3)
# RockPi boards and devices
_ROCK_PI_IDS = (
    ROCK_PI_S,
    ROCK_PI_4,
    ROCK_PI_4_C_PLUS,
    ROCK_PI_4_SE,
    ROCK_PI_X,
    ROCK_PI_E,
    RADXA_ZERO,
    RADXA_ZERO3,
    ROCK_PI_5,
    ROCK_PI_5C,
    RADXA_CM3,
    ROCK_PI_3A,
    ROCK_3B,
    ROCK_PI_3C,
)

# Vicharak Boards
_VICHARAK_BOARD_IDS = (VAAMAN, AXON)

# UDOO
_UDOO_BOARD_IDS = {UDOO_BOLT_V8: ("SC40-2000-0000-C0|C",), UDOO_X86: ("dummy",)}

# SeeedStudio boards
_SEEED_BOARD_IDS = (ODYSSEY_X86J41X5,)

# MaaXBoard boards
_MAAXBOARD_IDS = ("MAAXBOARD", "MAAXBOARD_MINI")

# Lichee RISC-V boards
_LICHEE_RISCV_IDS = (LICHEE_RV, LICHEEPI_4A)

# Siemens Simatic IOT2000 Gateways
SIEMENS_SIMATIC_IOT2050_ADV = "SIEMENS_SIMATIC_IOT2050_ADVANCED"
SIEMENS_SIMATIC_IOT2050_BASIC = "SIEMENS_SIMATIC_IOT2050_BASIC"

# Siemens Simatic IOT2000 Gateways
_SIEMENS_SIMATIC_IOT2000_IDS = (
    SIEMENS_SIMATIC_IOT2050_ADV,
    SIEMENS_SIMATIC_IOT2050_BASIC,
)

# Libre Computer Boards
AML_S905X_CC = "AML-S905X-CC"
ROC_RK3328_CC = "ROC-RK3328-CC"

# Libre Computer Boards
_LIBRE_COMPUTER_IDS = (
    AML_S905X_CC,
    ROC_RK3328_CC,
)

# NXP System on Module Computer boards
NXP_IMX8MPLUS_SOM = "NXP_IMX8MPLUS_SOM"

_NXP_SOM_IDS = (NXP_IMX8MPLUS_SOM,)

# Repka-Pi boards
REPKA_PI_3_H5 = "REPKA_PI_3_H5"
REPKA_PI_4_H6 = "REPKA_PI_4_H6"

# Repka-Pi
_REPKA_PI_IDS = (
    REPKA_PI_3_H5,
    REPKA_PI_4_H6,
)

_MILKV_IDS_ = (MILKV_DUO,)

# Luckfox
_LUCKFOX_IDS = (
    LUCKFOX_PICO,
    LUCKFOX_PICO_MAX,
    LUCKFOX_PICO_ULTRA,
    LUCKFOX_PICO_MINI,
    LUCKFOX_PICO_PLUS,
)

# Horizon
_HORIZON_IDS = (RDK_X3, RDK_X5)

_AMERIDROID_IDS = (INDIEDROID_NOVA,)

# Particle
_PARTICLE_IDS = (PARTICLE_TACHYON,)

# Agnostic board
OS_AGNOSTIC_BOARD = "OS_AGNOSTIC_BOARD"



# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
#
# SPDX-License-Identifier: MIT


"""
`adafruit_platformdetect.board`
================================================================================

Detect boards

* Author(s): Melissa LeBlanc-Williams

Implementation Notes
--------------------

**Software and Dependencies:**

* Linux and Python 3.7 or Higher

"""

import glob
import os
import re

try:
    from typing import Optional
except ImportError:
    pass

from adafruit_platformdetect.constants import boards, chips

__version__ = "3.85.0"
__repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_PlatformDetect.git"


class Board:
    """Attempt to detect specific boards."""

    def __init__(self, detector) -> None:
        self.detector = detector
        self._board_id = None

    # pylint: disable=invalid-name, protected-access, too-many-return-statements, too-many-lines
    @property
    def id(self) -> Optional[str]:
        """Return a unique id for the detected board, if any."""
        # There are some times we want to trick the platform detection
        # say if a raspberry pi doesn't have the right ID, or for testing

        # Caching
        if self._board_id:
            return self._board_id

        try:
            return os.environ["BLINKA_FORCEBOARD"]
        except (AttributeError, KeyError):  # no forced board, continue with testing!
            pass

        chip_id = self.detector.chip.id
        board_id = None

        if chip_id == chips.H3:
            board_id = self._armbian_id() or self._allwinner_variants_id()
        elif chip_id == chips.JH7110:
            board_id = self._starfive_id()
        elif chip_id == chips.BCM2XXX:
            board_id = self._pi_id()
        elif chip_id == chips.OS_AGNOSTIC:
            board_id = boards.OS_AGNOSTIC_BOARD
        elif chip_id == chips.AM625X:
            board_id = self._beaglebone_id()
        elif chip_id == chips.AM33XX:
            board_id = self._beaglebone_id()
        elif chip_id == chips.AM65XX:
            board_id = self._siemens_simatic_iot2000_id()
        elif chip_id == chips.AM67A:
            board_id = self._beagleyai_id()
        elif chip_id == chips.DRA74X:
            board_id = self._bbai_id()
        elif chip_id == chips.SUN4I:
            board_id = self._armbian_id()
        elif chip_id == chips.SUN7I:
            board_id = self._armbian_id()
        elif chip_id == chips.SUN8I:
            board_id = self._armbian_id() or self._allwinner_variants_id()
        elif chip_id == chips.SAMA5:
            board_id = self._sama5_id()
        elif chip_id == chips.IMX8MX:
            board_id = self._imx8mx_id()
        elif chip_id == chips.IMX8MP:
            board_id = self._imx8mp_id()
        elif chip_id == chips.IMX6ULL:
            board_id = self._imx6ull_id()
        elif chip_id == chips.S905Y2:
            board_id = boards.RADXA_ZERO
        elif chip_id == chips.ESP8266:
            board_id = boards.FEATHER_HUZZAH
        elif chip_id == chips.SAMD21:
            board_id = boards.FEATHER_M0_EXPRESS
        elif chip_id == chips.STM32F405:
            board_id = boards.PYBOARD
        elif chip_id == chips.RP2040:
            board_id = boards.RASPBERRY_PI_PICO
        elif chip_id == chips.S805:
            board_id = boards.ODROID_C1
        elif chip_id == chips.S905:
            board_id = boards.ODROID_C2
        elif chip_id == chips.S905X3:
            board_id = self._s905x3_id()
        elif chip_id == chips.S922X:
            board_id = boards.ODROID_N2
        elif chip_id == chips.A311D:
            board_id = boards.KHADAS_VIM3
        elif chip_id == chips.EXYNOS5422:
            board_id = boards.ODROID_XU4
        elif chip_id == chips.FT232H:
            board_id = boards.FTDI_FT232H
        elif chip_id == chips.FT2232H:
            board_id = boards.FTDI_FT2232H
        elif chip_id == chips.FT4232H:
            board_id = boards.FTDI_FT4232H
        elif chip_id == chips.SPIDRIVER:
            board_id = boards.EXCAMERA_SPIDRIVER
        elif chip_id == chips.APQ8016:
            board_id = boards.DRAGONBOARD_410C
        elif chip_id in (chips.T210, chips.T186, chips.T194, chips.T234, chips.T264):
            board_id = self._tegra_id()
        elif chip_id == chips.HFU540:
            board_id = self._sifive_id()
        elif chip_id == chips.C906:
            board_id = self._allwinner_id()
        elif chip_id == chips.JH71X0:
            board_id = self._beaglebone_id()
        elif chip_id == chips.MCP2221:
            board_id = boards.MICROCHIP_MCP2221
        elif chip_id == chips.BINHO:
            board_id = boards.BINHO_NOVA
        elif chip_id == chips.LPC4330:
            board_id = boards.GREATFET_ONE
        elif chip_id == chips.MIPS24KC:
            board_id = boards.ONION_OMEGA
        elif chip_id == chips.MIPS24KEC:
            board_id = boards.ONION_OMEGA2
        elif chip_id == chips.ZYNQ7000:
            board_id = self._pynq_id()
        elif chip_id == chips.A10:
            board_id = self._armbian_id()
        elif chip_id == chips.A20:
            board_id = self._armbian_id() or self._allwinner_variants_id()
        elif chip_id == chips.A64:
            board_id = self._pine64_id()
        elif chip_id == chips.H6:
            board_id = (
                self._pine64_id() or self._armbian_id() or self._repka_variants_id()
            )
        elif chip_id == chips.H5:
            board_id = (
                self._armbian_id()
                or self._allwinner_variants_id()
                or self._repka_variants_id()
            )
        elif chip_id == chips.T527:
            board_id = self._armbian_id() or self._allwinner_variants_id()
        elif chip_id == chips.H618:
            board_id = self._armbian_id() or self._allwinner_variants_id()
        elif chip_id == chips.H616:
            board_id = self._armbian_id() or self._allwinner_variants_id()
        elif chip_id == chips.A33:
            board_id = self._clockwork_pi_id()
        elif chip_id == chips.K1:
            board_id = self._armbian_id() or self._spacemit_variants_id()
        elif chip_id == chips.RZV2N:
            board_id = self._armbian_id() or self._renesas_variants_id()
        elif chip_id == chips.RZV2H:
            board_id = self._armbian_id() or self._renesas_variants_id()
        elif chip_id == chips.RK3308:
            board_id = self._rock_pi_id()
        elif chip_id == chips.RK3399:
            board_id = (
                self._rock_pi_id()
                or self._armbian_id()
                or self._diet_pi_id()
                or self._asus_tinker_board_id()
                or self._vivid_unit_id()
                or self._vicharak_id()
            )
        elif chip_id == chips.RK3399PRO:
            board_id = self._asus_tinker_board_id()
        elif chip_id == chips.RK3399_T:
            board_id = self._rock_pi_id() or self._armbian_id()
        elif chip_id == chips.ATOM_X5_Z8350:
            board_id = self._rock_pi_id()
        elif chip_id == chips.ATOM_J4105:
            board_id = self._j4105_id()
        elif chip_id == chips.RK3288:
            board_id = self._asus_tinker_board_id()
        elif chip_id == chips.RK3328:
            board_id = self._rock_pi_id() or self._libre_id()
        elif chip_id == chips.RK3566:
            board_id = self._rk3566_id()
        elif chip_id == chips.RK3568:
            board_id = self._rk3568_id()
        elif chip_id == chips.RK3588:
            board_id = (
                self._rock_pi_id()
                or self._orange_pi_id()
                or self._armbian_id()
                or self._rk3588_id()
                or self._ameridroid_id()
                or self._vicharak_id()
            )
        elif chip_id == chips.RK3588S:
            board_id = (
                self._orange_pi_id() or self._armbian_id() or self._ameridroid_id()
            )
        elif chip_id == chips.RYZEN_V1605B:
            board_id = self._udoo_id()
        elif chip_id == chips.PENTIUM_N3710:
            board_id = self._udoo_id()
        elif chip_id == chips.CELERON_N5105:
            board_id = self._intel_n_series_id()
        elif chip_id == chips.STM32MP157:
            board_id = self._stm32mp1_id()
        elif chip_id == chips.STM32MP157DAA1:
            board_id = self._stm32mp1_id()
        elif chip_id == chips.MT8167:
            board_id = boards.CORAL_EDGE_TPU_DEV_MINI
        elif chip_id == chips.RP2040_U2IF:
            board_id = self._rp2040_u2if_id()
        elif chip_id == chips.GENERIC_X86:
            board_id = boards.GENERIC_LINUX_PC
        elif chip_id == chips.TDA4VM:
            board_id = self._beaglebone_id() or self._tisk_id()
        elif chip_id == chips.D1_RISCV:
            board_id = self._armbian_id()
        elif chip_id == chips.S905X:
            board_id = boards.AML_S905X_CC
        elif chip_id == chips.CV1800B:
            board_id = boards.MILKV_DUO
        elif chip_id == chips.TH1520:
            board_id = boards.LICHEEPI_4A
        elif chip_id == chips.RV1103:
            board_id = self._rv1103_id()
        elif chip_id == chips.RV1106:
            board_id = self._rv1106_id()
        elif chip_id == chips.SUNRISE_X3:
            board_id = boards.RDK_X3
        elif chip_id == chips.SUNRISE_X5:
            board_id = boards.RDK_X5
        elif chip_id == chips.QCM6490:
            board_id = boards.PARTICLE_TACHYON
        self._board_id = board_id
        return board_id

    # pylint: enable=invalid-name
    def _starfive_id(self) -> Optional[str]:
        model = None
        model_value = self.detector.get_device_model()
        if "VisionFive" in model_value and "V2" in model_value:
            model = boards.VISIONFIVE2
        return model

    @property
    def any_starfive_id(self):
        """Check whether the current board is any Pine64 device."""
        return self.id in boards._STARFIVE_BOARD_IDS

    def _pi_id(self) -> Optional[str]:
        """Try to detect id of a Raspberry Pi."""
        # Check for Pi boards:
        pi_rev_code = self._pi_rev_code()
        if pi_rev_code:
            from adafruit_platformdetect.revcodes import PiDecoder

            try:
                decoder = PiDecoder(pi_rev_code)
                model = boards._PI_MODELS[decoder.type_raw]
                if isinstance(model, dict):
                    model = model[decoder.revision]
                return model
            except ValueError:
                pass
        # We may be on a non-Raspbian OS, so try to lazily determine
        # the version based on `get_device_model`
        else:
            pi_model = self.detector.get_device_model()
            if pi_model:
                pi_model = pi_model.upper().replace(" ", "_")
                if "PLUS" in pi_model:
                    re_model = re.search(r"(RASPBERRY_PI_\d).*([AB]_*)(PLUS)", pi_model)
                elif "CM" in pi_model:  # untested for Compute Module
                    re_model = re.search(r"(RASPBERRY_PI_CM)(\d)", pi_model)
                else:  # untested for non-plus models
                    re_model = re.search(r"(RASPBERRY_PI_\d).*([AB])", pi_model)

                if re_model:
                    pi_model = "".join(re_model.groups())
                    available_models = boards._PI_MODELS.values()
                    for model in available_models:
                        # Account for the PI_B_REV1/2 case
                        if isinstance(model, dict) and pi_model in model:
                            return model[pi_model]
                        if model == pi_model:
                            return model

        return None

    def _pi_rev_code(self) -> Optional[str]:
        """Attempt to find a Raspberry Pi revision code for this board."""
        # 2708 is Pi 1
        # 2709 is Pi 2
        # 2835 is Pi 3 (or greater) on 4.9.x kernel
        # Anything else is not a Pi.
        if self.detector.chip.id != chips.BCM2XXX:
            # Something else, not a Pi.
            return None
        rev = self.detector.get_cpuinfo_field("Revision")

        if rev is not None:
            return rev

        try:
            with open("/proc/device-tree/system/linux,revision", "rb") as revision:
                rev_bytes = revision.read()

                if rev_bytes[:1] == b"\x00":
                    rev_bytes = rev_bytes[1:]

                return rev_bytes.hex()
        except FileNotFoundError:
            return None

    # pylint: disable=no-self-use
    def _beaglebone_id(self) -> Optional[str]:
        """Try to detect id of a Beaglebone."""
        board_value = self.detector.get_device_compatible()
        # Older Builds
        if "freedom-u74-arty" in board_value:
            return boards.BEAGLEV_STARLIGHT

        # Newer Builds
        if "beaglev-starlight" in board_value:
            return boards.BEAGLEV_STARLIGHT

        # find device alias at i2c address 0x50 (0-00500, 0-00501, etc)
        nvmem_devices = glob.glob("/sys/bus/nvmem/devices/0-0050*")
        # do not expect there to be anything but one eeprom
        if len(nvmem_devices) != 1:
            return None

        eeprom_dir = nvmem_devices[0]
        try:
            with open(f"{eeprom_dir}/nvmem", "rb") as eeprom:
                eeprom_bytes = eeprom.read(16)
        except FileNotFoundError:
            try:
                # Special Case for AI64
                with open("/sys/bus/nvmem/devices/2-00500/nvmem", "rb") as eeprom:
                    eeprom_bytes = eeprom.read(16)
            except FileNotFoundError:
                return None

        if eeprom_bytes[:4] != b"\xaaU3\xee":
            return None

        # special condition for BeagleBone Green rev. 1A
        # refer to GitHub issue #57 in this repo for more info
        if eeprom_bytes == b"\xaaU3\xeeA335BNLT\x1a\x00\x00\x00":
            return boards.BEAGLEBONE_GREEN

        # BeaglePlay Special Condition
        # new Beagle EEPROM IDs are 24 Bit, so we need to verify full range
        if eeprom_bytes == b"\xaaU3\xee\x017\x00\x10.\x00BEAGLE":
            with open("/sys/bus/nvmem/devices/0-00500/nvmem", "rb") as eeprom:
                eeprom_bytes = eeprom.read(24)
            if eeprom_bytes == b"\xaaU3\xee\x017\x00\x10.\x00BEAGLEPLAY-A0-":
                return boards.BEAGLE_PLAY

        id_string = eeprom_bytes[4:].decode("ascii")
        for model, bb_ids in boards._BEAGLEBONE_BOARD_IDS.items():
            for bb_id in bb_ids:
                if id_string == bb_id[1]:
                    return model

        board_value = self.detector.get_armbian_release_field("BOARD")
        return None

    # pylint: enable=no-self-use
    def _beagleyai_id(self) -> Optional[str]:
        """Try to detect id of a BeagleY-AI board."""
        board_value = self.detector.get_device_model()
        if "BeagleY-AI" in board_value:
            return boards.BEAGLEY_AI
        return None

    def _bbai_id(self) -> Optional[str]:
        """Try to detect id of a Beaglebone AI related board."""
        board_value = self.detector.get_device_model()
        if "BeagleBone AI" in board_value:
            return boards.BEAGLEBONE_AI
        return None

    def _tisk_id(self) -> Optional[str]:
        """Try to detect the id of aarch64 board."""
        compatible = self.detector.get_device_compatible()
        print(compatible)
        if not compatible:
            return None
        compats = compatible.split("\x00")
        for board_id, board_compats in boards._TI_SK_BOARD_IDS:
            if any(v in compats for v in board_compats):
                return board_id
        return None

    # pylint: disable=too-many-return-statements
    def _armbian_id(self) -> Optional[str]:
        """Get the current board via the ARMBIAN release field."""
        board_value = self.detector.get_armbian_release_field("BOARD")
        board = None

        if board_value == "orangepipc":
            board = boards.ORANGE_PI_PC
        elif board_value == "orangepi-r1":
            board = boards.ORANGE_PI_R1
        elif board_value == "orangepizero":
            board = boards.ORANGE_PI_ZERO
        elif board_value == "orangepione":
            board = boards.ORANGE_PI_ONE
        elif board_value == "orangepilite":
            board = boards.ORANGE_PI_LITE
        elif board_value == "orangepiplus2e":
            board = boards.ORANGE_PI_PLUS_2E
        elif board_value == "orangepipcplus":
            board = boards.ORANGE_PI_PC_PLUS
        elif board_value == "pinebook-a64":
            board = boards.PINEBOOK
        elif board_value == "pineH64":
            board = boards.PINEH64
        elif board_value == "orangepi2":
            board = boards.ORANGE_PI_2
        elif board_value == "orangepipc2":
            board = boards.ORANGE_PI_PC2
        elif board_value == "orangepizero3":
            board = boards.ORANGE_PI_ZERO_3
        elif board_value == "orangepi3b":
            board = boards.ORANGE_PI_3B
        elif board_value == "orangepi3":
            board = boards.ORANGE_PI_3
        elif board_value == "orangepi3-lts":
            board = boards.ORANGE_PI_3_LTS
        elif board_value == "orangepi4":
            board = boards.ORANGE_PI_4
        elif board_value == "orangepi4-lts":
            board = boards.ORANGE_PI_4_LTS
        elif board_value == "orangepi5-plus":
            board = boards.ORANGE_PI_5_PLUS
        elif board_value == "orangepi5":
            board = boards.ORANGE_PI_5
        elif board_value == "orangepi5-pro":
            board = boards.ORANGE_PI_5_PRO
        elif board_value == "bananapim2zero":
            board = boards.BANANA_PI_M2_ZERO
        elif board_value == "bananapim2plus":
            board = boards.BANANA_PI_M2_PLUS
        elif board_value == "bananapim2berry":
            board = boards.BANANA_PI_M2_BERRY
        elif board_value == "bananapim4berry":
            board = boards.BANANA_PI_M4_BERRY
        elif board_value == "bananapim4zero":
            board = boards.BANANA_PI_M4_ZERO
        elif board_value == "bananapim5":
            board = boards.BANANA_PI_M5
        elif board_value == "bananapif3":
            board = boards.BANANA_PI_F3
        elif board_value == "bananapif5":
            board = boards.BANANA_PI_F5
        elif board_value == "bananapiai2n":
            board = boards.BANANA_PI_AI2N
        elif board_value == "bananapiai2h":
            board = boards.BANANA_PI_AI2H
        elif board_value == "orangepizeroplus2-h5":
            board = boards.ORANGE_PI_ZERO_PLUS_2H5
        elif board_value == "orangepizeroplus":
            board = boards.ORANGE_PI_ZERO_PLUS
        elif board_value == "orangepizero2":
            board = boards.ORANGE_PI_ZERO_2
        elif board_value == "nanopiair":
            board = boards.NANOPI_NEO_AIR
        elif board_value == "nanopiduo2":
            board = boards.NANOPI_DUO2
        elif board_value == "nanopineo":
            board = boards.NANOPI_NEO
        elif board_value == "nanopineo2":
            board = boards.NANOPI_NEO_2
        elif board_value == "nezha":
            board = boards.LICHEE_RV
        elif board_value == "pcduino2":
            board = boards.PCDUINO2
        elif board_value == "pcduino3":
            board = boards.PCDUINO3
        elif board_value == "rock-3a":
            board = boards.ROCK_PI_3A
        elif board_value == "radxa-zero3":
            board = boards.RADXA_ZERO3
        elif board_value == "repka-pi3-h5":
            board = boards.REPKA_PI_3_H5
        elif board_value == "repka-pi4-h6":
            board = boards.REPKA_PI_4_H6
        elif board_value == "milkv_duo":
            board = boards.MILKV_DUO
        return board

    # pylint: enable=too-many-return-statements

    def _diet_pi_id(self) -> Optional[str]:
        board_value = self.detector.get_device_model()
        if "OrangePi 4" in board_value:
            return boards.ORANGE_PI_4
        return None

    def _ameridroid_id(self) -> Optional[str]:
        board_value = self.detector.get_device_model().upper()
        if "INDIEDROID NOVA" in board_value:
            return boards.INDIEDROID_NOVA
        return None

    def _orange_pi_id(self) -> Optional[str]:
        # pylint: disable=too-many-return-statements
        board_value = self.detector.get_device_model()
        if "OPi 5 Max" in board_value:
            return boards.ORANGE_PI_5_MAX
        if "OPi 5 Pro" in board_value:
            return boards.ORANGE_PI_5_PRO
        if "Orange Pi 5 Max" in board_value:
            return boards.ORANGE_PI_5_MAX
        if "Orange Pi 5 Plus" in board_value:
            return boards.ORANGE_PI_5_PLUS
        if "Orange Pi 5" in board_value:
            return boards.ORANGE_PI_5
        if "Orange Pi 3B" in board_value:
            return boards.ORANGE_PI_3B
        return None

    # pylint: enable=too-many-return-statements

    def _sama5_id(self) -> Optional[str]:
        """Check what type sama5 board."""
        board_value = self.detector.get_device_model()
        if "Giant Board" in board_value:
            return boards.GIANT_BOARD
        return None

    def _s905x3_id(self) -> Optional[str]:
        """Check what type S905X3 board."""
        board_value = self.detector.get_device_model()
        if "Bananapi BPI-M5" in board_value:
            return boards.BANANA_PI_M5
        return boards.ODROID_C4

    def _stm32mp1_id(self) -> Optional[str]:
        """Check what type stm32mp1 board."""
        board_value = self.detector.get_device_model()
        if "STM32MP157C-DK2" in board_value:
            return boards.STM32MP157C_DK2
        if "LubanCat" in board_value:
            return boards.LUBANCAT_STM32MP157
        if "OSD32MP1-BRK" in board_value:
            return boards.OSD32MP1_BRK
        if "OSD32MP1-RED" in board_value:
            return boards.OSD32MP1_RED
        if "STM32MP1XX OLinuXino" in board_value:
            return boards.STMP157_OLINUXINO_LIME2
        return None

    def _imx8mx_id(self) -> Optional[str]:
        """Check what type iMX8M board."""
        board_value = self.detector.get_device_model()
        if "FSL i.MX8MM DDR4 EVK" in board_value:
            return boards.MAAXBOARD_MINI
        if "Freescale i.MX8MQ EVK" in board_value:
            return boards.MAAXBOARD
        if "Phanbell" in board_value:
            return boards.CORAL_EDGE_TPU_DEV
        return None

    def _imx8mp_id(self) -> Optional[str]:
        """Check what type iMX8M board."""
        board_value = self.detector.get_device_model()
        if "NXP i.MX8MPlus SOM" in board_value:
            return boards.NXP_IMX8MPLUS_SOM
        return None

    def _imx6ull_id(self) -> Optional[str]:
        """Check what type iMX6ULL board."""
        board_value = self.detector.get_device_model()
        if "LubanCat" in board_value or "Embedfire" in board_value:
            return boards.LUBANCAT_IMX6ULL
        return None

    def _tegra_id(self) -> Optional[str]:
        """Try to detect the id of aarch64 board."""
        compatible = self.detector.get_device_compatible()
        if not compatible:
            return None
        compats = compatible.split("\x00")
        for board_id, board_compats in boards._JETSON_IDS:
            if any(v in compats for v in board_compats):
                return board_id
        return None

    def _sifive_id(self) -> Optional[str]:
        """Try to detect the id for Sifive RISCV64 board."""
        board_value = self.detector.get_device_model()
        if "hifive-unleashed-a00" in board_value:
            return boards.SIFIVE_UNLEASHED
        return None

    def _allwinner_id(self) -> Optional[str]:
        """Try to detect the id for Allwiner D1 board."""
        board_value = self.detector.get_device_model()
        if "sun20iw1p1" in board_value:
            return boards.ALLWINER_D1
        return None

    def _pine64_id(self) -> Optional[str]:
        """Try to detect the id for Pine64 board or device."""
        board_value = self.detector.get_device_model()
        board = None
        if "pinephone" in board_value.lower():
            board = boards.PINEPHONE
        elif "pine64" in board_value.lower():
            board = boards.PINE64
        elif "pine h64" in board_value.lower():
            board = boards.PINEH64
        elif "pinebook" in board_value.lower():
            board = boards.PINEBOOK
        elif "sopine" in board_value.lower():
            board = boards.SOPINE
        return board

    # pylint: disable=no-self-use
    def _pynq_id(self) -> Optional[str]:
        """Try to detect the id for Xilinx PYNQ boards."""
        try:
            with open(
                "/proc/device-tree/chosen/pynq_board", "r", encoding="utf-8"
            ) as board_file:
                board_model = board_file.read()
                match = board_model.upper().replace("-", "_").rstrip("\x00")
                for model in boards._PYNQ_IDS:
                    if model == match:
                        return model

                return None

        except FileNotFoundError:
            return None

    def _rk3566_id(self) -> Optional[str]:
        """Check what type of rk3566 board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "LubanCat-Zero" in board_value:
            board = boards.LUBANCAT_ZERO
        if board_value and any(x in board_value for x in ("LubanCat1", "LubanCat-1")):
            board = boards.LUBANCAT1
        if board_value and "Radxa CM3 IO" in board_value:
            board = boards.RADXA_CM3
        if board_value and "Radxa ZERO 3" in board_value:
            board = boards.RADXA_ZERO3
        if board_value and "Radxa ROCK3 Model C" in board_value:
            board = boards.ROCK_PI_3C
        if board_value and "Rockchip RK3566 OPi 3B" in board_value:
            board = boards.ORANGE_PI_3B
        if board_value and "Hardkernel ODROID-M1S" in board_value:
            board = boards.ODROID_M1S
        elif "quartz64-a" in board_value.lower():
            board = boards.QUARTZ64_A
        return board

    def _rk3568_id(self) -> Optional[str]:
        """Check what type of rk3568 board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and any(x in board_value for x in ("LubanCat2", "LubanCat-2")):
            board = boards.LUBANCAT2
        if board_value and "ROCK3 Model A" in board_value:
            board = boards.ROCK_PI_3A
        if board_value and "ROCK 3 Model B" in board_value:
            board = boards.ROCK_3B
        if board_value and "Hardkernel ODROID-M1" in board_value:
            board = boards.ODROID_M1
        return board

    def _rk3588_id(self) -> Optional[str]:
        """Check what type of rk3588 board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "LubanCat-4" in board_value:
            board = boards.LUBANCAT4
        if board_value and "LubanCat-5" in board_value:
            board = boards.LUBANCAT5
        return board

    def _rock_pi_id(self) -> Optional[str]:
        """Check what type of Rock Pi board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "ROCK Pi S" in board_value:
            board = boards.ROCK_PI_S
        if board_value and "ROCK PI 4" in board_value.upper():
            board = boards.ROCK_PI_4
        if board_value and "ROCK PI E" in board_value.upper():
            board = boards.ROCK_PI_E
        if self.detector.check_board_name_value() == "ROCK Pi X":
            board = boards.ROCK_PI_X
        if board_value and "ROCK 5C" in board_value.upper():
            board = boards.ROCK_PI_5C
        elif board_value and "ROCK 5" in board_value.upper():
            board = boards.ROCK_PI_5
        if board_value and "RADXA ROCK 4C+" in board_value.upper():
            board = boards.ROCK_PI_4_C_PLUS
        if board_value and "RADXA ROCK 4SE" in board_value.upper():
            board = boards.ROCK_PI_4_SE
        if board_value and "ROCK3 Model A" in board_value:
            board = boards.ROCK_PI_3A
        return board

    def _vicharak_id(self) -> Optional[str]:
        """Check what type of Vicharak Board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "VAAMAN" in board_value.upper():
            board = boards.VAAMAN
        if board_value and "AXON" in board_value.upper():
            board = boards.AXON
        return board

    def _libre_id(self) -> Optional[str]:
        """Check what type of Libre Computer board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "Libre Computer ROC-RK3328-CC" in board_value:
            board = boards.ROC_RK3328_CC
        return board

    def _clockwork_pi_id(self) -> Optional[str]:
        """Check what type of Clockwork Pi board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "Clockwork CPI3" in board_value:
            board = boards.CLOCKWORK_CPI3
        return board

    def _udoo_id(self) -> Optional[str]:
        """Try to detect the id of udoo board."""
        board_asset_tag = self.detector.check_board_asset_tag_value()
        for board_id, board_tags in boards._UDOO_BOARD_IDS.items():
            if any(v == board_asset_tag for v in board_tags):
                return board_id

        if self.detector.check_board_name_value() == "UDOO x86":
            return boards.UDOO_X86

        return None

    def _intel_n_series_id(self) -> Optional[str]:
        """Try to detect the id of an Intel N-Series board."""
        if self.detector.check_board_name_value() == "ODROID-H3":
            return boards.ODROID_H3

        return None

    def _j4105_id(self) -> Optional[str]:
        """Try to detect the id of J4105 board."""
        try:
            with open(
                "/sys/devices/virtual/dmi/id/board_name", "r", encoding="utf-8"
            ) as board_name:
                board_value = board_name.read().rstrip()
            if board_value in ("ODYSSEY-X86J41X5", "ODYSSEY-X86J41O5"):
                return boards.ODYSSEY_X86J41X5
            return None
        except FileNotFoundError:
            return None

    def _asus_tinker_board_id(self) -> Optional[str]:
        """Check what type of Tinker Board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "ASUS Tinker Board" in board_value:
            board = boards.ASUS_TINKER_BOARD
        if board_value and "ASUS TINKER BOARD 2" in board_value:
            board = boards.ASUS_TINKER_BOARD_2
        if board_value and "ASUS_TINKER_EDGE_R" in board_value:
            board = boards.ASUS_TINKER_EDGE_R

        return board

    def _vivid_unit_id(self) -> Optional[str]:
        """Check what type of vivid unit."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "RK3399 VIVID" in board_value:
            board = boards.VIVID_UNIT
        return board

    def _pcduino_board_id(self) -> Optional[str]:
        """Check on the type of Pcduino"""
        board_value = self.detector.get_device_model()
        board = None
        if "pcduino2" in board_value.lower():
            board = boards.PCDUINO2
        if "pcduino3" in board_value.lower():
            board = boards.PCDUINO3
        return board

    def _allwinner_variants_id(self) -> Optional[str]:
        """Try to detect the id of allwinner based board. (orangepi, nanopi)"""
        board_value = self.detector.get_device_model()
        board = None
        if not board_value:
            return board
        board_value = board_value.lower()
        chip_id = self.detector.chip.id

        if "banana pro" in board_value:
            board = boards.LEMAKER_BANANA_PRO

        if any(x in board_value for x in ("banana pi", "bananapi")):
            if "m2 berry" in board_value:
                board = boards.BANANA_PI_M2_BERRY
            elif "m4berry" in board_value or "m4 berry" in board_value:
                board = boards.BANANA_PI_M4_BERRY
            elif "m4zero" in board_value or "m4 zero" in board_value:
                board = boards.BANANA_PI_M4_ZERO
            elif "f5" in board_value or "bpi-f5" in board_value:
                board = boards.BANANA_PI_F5

        if "nanopi" in board_value:
            if "neo" in board_value and "SUN8I" in chip_id:
                board = boards.NANOPI_NEO_AIR
            elif "neo2" in board_value and "H5" in chip_id:
                board = boards.NANOPI_NEO_2
        elif any(x in board_value for x in ("orange pi", "orangepi")):
            if "zero" in board_value:
                if "H5" in chip_id:
                    board = boards.ORANGE_PI_ZERO_PLUS_2H5
                elif "H616" in chip_id:
                    board = boards.ORANGE_PI_ZERO_2
        elif "walnutpi-1b-emmc" in board_value:
            board = boards.WALNUT_PI_1B_EMMC
        elif "walnutpi-1b" in board_value:
            board = boards.WALNUT_PI_1B
            # TODO: Add other specifc board contexts here

        elif "lime2" in board_value:
            board = boards.OLIMEX_LIME2
        return board

    def _spacemit_variants_id(self) -> Optional[str]:
        """Try to detect the id of spacemit based board. (bananapi)"""
        board_value = self.detector.get_device_model()
        board = None
        if not board_value:
            return board
        board_value = board_value.lower()

        if any(x in board_value for x in ("banana pi", "bananapi")):
            if "bpi-f3" in board_value:
                board = boards.BANANA_PI_F3

        if "spacemit" in board_value:
            if "deb1" in board_value:
                board = boards.BANANA_PI_F3

        return board

    def _renesas_variants_id(self) -> Optional[str]:
        """Try to detect the id of renesas based board. (bananapi)"""
        board_value = self.detector.get_device_model()
        board = None
        if not board_value:
            return board
        board_value = board_value.lower()

        if any(x in board_value for x in ("banana pi", "bananapi")):
            if "bpi-ai2n" in board_value:
                board = boards.BANANA_PI_AI2N
            if "bpi-ai2h" in board_value:
                board = boards.BANANA_PI_AI2H

        return board

    def _repka_variants_id(self) -> Optional[str]:
        board_value = self.detector.get_device_model()
        board = None
        if not board_value:
            return board
        board_value = board_value.lower()
        if "repka-pi3-h5" in board_value:
            board = boards.REPKA_PI_3_H5
        if "repka-pi4-h6" in board_value:
            board = boards.REPKA_PI_4_H6

        return board

    # pylint: disable=too-many-return-statements

    def _rp2040_u2if_id(self) -> Optional[str]:
        import hid

        # look for it based on PID/VID
        for dev in hid.enumerate():
            # Raspberry Pi Pico
            vendor = dev["vendor_id"]
            product = dev["product_id"]
            if vendor == 0xCAFE and product == 0x4005:
                return boards.PICO_U2IF
            if vendor == 0xCAFF and product == 0x4005:
                return boards.RADXA_X4_U2IF
            if vendor == 0x239A:
                # Feather RP2040
                if product == 0x00F1:
                    return boards.FEATHER_U2IF
                # Itsy Bitsy RP2040
                if product == 0x00FD:
                    return boards.ITSYBITSY_U2IF
                # QT Py RP2040
                if product == 0x00F7:
                    return boards.QTPY_U2IF
                # QT2040 Trinkey
                if product == 0x0109:
                    return boards.QT2040_TRINKEY_U2IF
                # MacroPad RP2040
                if product == 0x0107:
                    return boards.MACROPAD_U2IF
                # Feather RP2040 ThinkInk
                if product == 0x812C:
                    return boards.FEATHER_EPD_U2IF
                # Feather RP2040 RFM
                if product == 0x812E:
                    return boards.FEATHER_RFM_U2IF
                # Feather RP2040 CAN
                if product == 0x8130:
                    return boards.FEATHER_CAN_U2IF
                # KB2040 Kee Board
                if product == 0x0105:
                    return boards.KB2040_U2IF
            if vendor == 0x2E8A and product == 0x103A:
                return boards.RP2040_ONE_U2IF
        # Will only reach here if a device was added in chip.py but here.
        raise RuntimeError("RP2040_U2IF device was added to chip but not board.")

    # pylint: enable=too-many-return-statements

    def _siemens_simatic_iot2000_id(self) -> Optional[str]:
        """Try to detect if this is a IOT2050 Gateway."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "SIMATIC IOT2050 Advanced" in board_value:
            board = boards.SIEMENS_SIMATIC_IOT2050_ADV
        elif board_value and "SIMATIC IOT2050 Basic" in board_value:
            board = boards.SIEMENS_SIMATIC_IOT2050_BASIC
        return board

    def _rv1103_id(self) -> Optional[str]:
        """Check what type of rv1103 board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "Luckfox Pico Mini" in board_value:
            board = boards.LUCKFOX_PICO_MINI
        elif board_value and "Luckfox Pico Plus" in board_value:
            board = boards.LUCKFOX_PICO_PLUS
        elif board_value and "Luckfox Pico" in board_value:
            board = boards.LUCKFOX_PICO
        return board

    def _rv1106_id(self) -> Optional[str]:
        """Check what type of rv1106 board."""
        board_value = self.detector.get_device_model()
        board = None
        if board_value and "Luckfox Pico Max" in board_value:
            board = boards.LUCKFOX_PICO_MAX
        elif board_value and "Luckfox Pico Ultra" in board_value:
            board = boards.LUCKFOX_PICO_ULTRA
        return board

    @property
    def any_siemens_simatic_iot2000(self) -> bool:
        """Check whether the current board is a SIEMENS SIMATIC IOT2000 Gateway."""
        return self.id in boards._SIEMENS_SIMATIC_IOT2000_IDS

    @property
    def any_walnutpi(self) -> bool:
        """Check whether the current board is any defined Walnut Pi."""
        return self.id in boards._WALNUT_PI_IDS

    @property
    def any_nanopi(self) -> bool:
        """Check whether the current board is any defined Nano Pi."""
        return self.id in boards._NANOPI_IDS

    @property
    def any_96boards(self) -> bool:
        """Check whether the current board is any 96boards board."""
        return self.id in boards._LINARO_96BOARDS_IDS

    @property
    def any_raspberry_pi(self) -> bool:
        """Check whether the current board is any Raspberry Pi."""
        return self._pi_rev_code() is not None

    @property
    def any_raspberry_pi_40_pin(self) -> bool:
        """Check whether the current board is any 40-pin Raspberry Pi."""
        return self.id in boards._RASPBERRY_PI_40_PIN_IDS

    @property
    def any_raspberry_pi_cm(self) -> bool:
        """Check whether the current board is any Compute Module Raspberry Pi."""
        return self.id in boards._RASPBERRY_PI_CM_IDS

    @property
    def any_raspberry_pi_4_board(self) -> bool:
        """Check whether the current board is any Raspberry Pi 4."""
        return self.id in boards._RASPBERRY_PI_4_IDS

    @property
    def any_raspberry_pi_5_board(self) -> bool:
        """Check whether the current board is any Raspberry Pi 5."""
        return self.id in boards._RASPBERRY_PI_5_IDS

    @property
    def any_beaglebone(self) -> bool:
        """Check whether the current board is any Beaglebone-family system."""
        return self.id in boards._BEAGLEBONE_IDS

    @property
    def any_ameridroid(self) -> bool:
        """Check whether the current board is any Ameridroid device."""
        return self.id in boards._AMERIDROID_IDS

    @property
    def any_orange_pi(self) -> bool:
        """Check whether the current board is any defined Orange Pi."""
        return self.id in boards._ORANGE_PI_IDS

    @property
    def any_lubancat(self) -> bool:
        """Check whether the current board is any defined lubancat."""
        return self.id in boards._LUBANCAT_IDS

    @property
    def any_coral_board(self) -> bool:
        """Check whether the current board is any defined Coral."""
        return self.id in boards._CORAL_IDS

    @property
    def any_pynq_board(self) -> bool:
        """Check whether the current board is any defined PYNQ Board."""
        return self.id in boards._PYNQ_IDS

    @property
    def any_giant_board(self) -> bool:
        """Check whether the current board is any defined Giant Board."""
        return self.GIANT_BOARD

    @property
    def any_odroid_40_pin(self) -> bool:
        """Check whether the current board is any defined 40-pin Odroid."""
        return self.id in boards._ODROID_40_PIN_IDS

    @property
    def any_odroid_mini_pc(self) -> bool:
        """Check whether the current board is any defined Odroid Mini PC."""
        return self.id in boards._ODROID_MINI_PC_IDS

    @property
    def khadas_vim3_40_pin(self) -> bool:
        """Check whether the current board is any defined 40-pin Khadas VIM3."""
        return self.id in boards._KHADAS_40_PIN_IDS

    @property
    def any_jetson_board(self) -> bool:
        """Check whether the current board is any defined Jetson Board."""
        return self.id in [v[0] for v in boards._JETSON_IDS]

    @property
    def any_sifive_board(self) -> bool:
        """Check whether the current board is any defined Jetson Board."""
        return self.id in boards._SIFIVE_IDS

    @property
    def any_onion_omega_board(self) -> bool:
        """Check whether the current board is any defined OpenWRT board."""
        return self.id in boards._ONION_OMEGA_BOARD_IDS

    @property
    def any_pine64_board(self) -> bool:
        """Check whether the current board is any Pine64 device."""
        return self.id in boards._PINE64_DEV_IDS

    @property
    def any_milkv_board(self) -> bool:
        """Check whether the current board is any MilkV device."""
        return self.id in boards._MILKV_IDS_

    @property
    def any_rock_pi_board(self) -> bool:
        """Check whether the current board is any Rock Pi device."""
        return self.id in boards._ROCK_PI_IDS

    @property
    def any_vicharak_board(self) -> bool:
        """Check whether the current board is any vicharak device."""
        return self.id in boards._VICHARAK_BOARD_IDS

    @property
    def any_clockwork_pi_board(self) -> bool:
        """Check whether the current board is any Clockwork Pi device."""
        return self.CLOCKWORK_CPI3

    @property
    def any_udoo_board(self) -> bool:
        """Check to see if the current board is an UDOO board"""
        return self.id in boards._UDOO_BOARD_IDS

    @property
    def any_seeed_board(self) -> bool:
        """Check to see if the current board is an SEEED board"""
        return self.id in boards._SEEED_BOARD_IDS

    @property
    def any_asus_tinker_board(self) -> bool:
        """Check to see if the current board is an ASUS Tinker Board"""
        return self.id in boards._ASUS_TINKER_BOARD_IDS

    @property
    def any_pcduino_board(self) -> bool:
        """Check whether the current board is any Pcduino board"""
        return self.id in boards._PCDUINO_DEV_IDS

    @property
    def any_stm32mp1(self) -> bool:
        """Check whether the current board is any stm32mp1 board."""
        return self.id in boards._STM32MP1_IDS

    @property
    def any_bananapi(self) -> bool:
        """Check whether the current board is any BananaPi-family system."""
        return self.id in boards._BANANA_PI_IDS

    @property
    def any_lemaker(self) -> bool:
        """Check whether the current board is any LeMaker board."""
        return self.id in boards._LEMAKER_IDS

    @property
    def any_maaxboard(self) -> bool:
        """Check whether the current board is any BananaPi-family system."""
        return self.id in boards._MAAXBOARD_IDS

    @property
    def any_tisk_board(self) -> bool:
        """Check whether the current board is any defined TI SK Board."""
        return self.id in [v[0] for v in boards._TI_SK_BOARD_IDS]

    @property
    def any_lichee_riscv_board(self) -> bool:
        """Check whether the current board is any defined Lichee RISC-V."""
        return self.id in boards._LICHEE_RISCV_IDS

    @property
    def any_libre_computer_board(self) -> bool:
        """Check whether the current board is any defined Libre Computer board."""
        return self.id in boards._LIBRE_COMPUTER_IDS

    @property
    def any_nxp_navq_board(self) -> bool:
        """Check whether the current board is any NXP NavQ board"""
        return self.id in boards._NXP_SOM_IDS

    @property
    def any_olimex_board(self):
        """Check whether the current board is any Olimex device."""
        return self.id in boards._OLIMEX_IDS

    @property
    def any_repka_board(self):
        """Check whether the current board is any Repka device."""
        return self.id in boards._REPKA_PI_IDS

    @property
    def any_luckfox_pico_board(self):
        """Check whether the current board is any Luckfox Pico device."""
        return self.id in boards._LUCKFOX_IDS

    @property
    def any_vivid_unit(self):
        """Check whether the current board is any Vivid Unit device."""
        return self.id in boards._VIVID_UNIT_IDS

    @property
    def any_horizon_board(self):
        """Check whether the current board is any Horizon device."""
        return self.id in boards._HORIZON_IDS

    @property
    def any_particle_board(self):
        """Check whether the current board is any Particle device."""
        return self.id in boards._PARTICLE_IDS

    @property
    def os_environ_board(self) -> bool:
        """Check whether the current board is an OS environment variable special case."""

        def lazily_generate_conditions():
            yield self.board.FTDI_FT232H
            yield self.board.FTDI_FT2232H
            yield self.board.FTDI_FT4232H
            yield self.board.MICROCHIP_MCP2221
            yield self.board.BINHO_NOVA
            yield self.board.GREATFET_ONE
            yield self.board.PICO_U2IF
            yield self.board.FEATHER_U2IF
            yield self.board.FEATHER_CAN_U2IF
            yield self.board.FEATHER_EPD_U2IF
            yield self.board.FEATHER_RFM_U2IF
            yield self.board.ITSYBITY_U2IF
            yield self.board.MACROPAD_U2IF
            yield self.board.QTPY_U2IF
            yield self.board.QT2040_TRINKEY_U2IF
            yield self.board.KB2040_U2IF
            yield self.board.RP2040_ONE_U2IF
            yield self.board.RADXA_X4_U2IF
            yield self.board.OS_AGNOSTIC_BOARD

        return any(condition for condition in lazily_generate_conditions())

    @property
    def any_embedded_linux(self) -> bool:
        """Check whether the current board is any embedded Linux device."""

        def lazily_generate_conditions():
            yield self.any_raspberry_pi_40_pin
            yield self.any_raspberry_pi
            yield self.any_beaglebone
            yield self.any_ameridroid
            yield self.any_orange_pi
            yield self.any_nanopi
            yield self.any_giant_board
            yield self.any_jetson_board
            yield self.any_coral_board
            yield self.any_odroid_40_pin
            yield self.any_odroid_mini_pc
            yield self.khadas_vim3_40_pin
            yield self.any_96boards
            yield self.any_sifive_board
            yield self.any_onion_omega_board
            yield self.any_pine64_board
            yield self.any_pynq_board
            yield self.any_rock_pi_board
            yield self.any_clockwork_pi_board
            yield self.any_udoo_board
            yield self.any_seeed_board
            yield self.any_asus_tinker_board
            yield self.any_stm32mp1
            yield self.any_lubancat
            yield self.any_bananapi
            yield self.any_lemaker
            yield self.any_maaxboard
            yield self.any_tisk_board
            yield self.any_siemens_simatic_iot2000
            yield self.any_lichee_riscv_board
            yield self.any_pcduino_board
            yield self.any_libre_computer_board
            yield self.generic_linux
            yield self.any_nxp_navq_board
            yield self.any_walnutpi
            yield self.any_olimex_board
            yield self.any_repka_board
            yield self.any_milkv_board
            yield self.any_luckfox_pico_board
            yield self.any_vivid_unit
            yield self.any_starfive_id
            yield self.any_horizon_board
            yield self.any_particle_board

        return any(condition for condition in lazily_generate_conditions())

    @property
    def generic_linux(self) -> bool:
        """Check whether the current board is an Generic Linux System."""
        return self.id == boards.GENERIC_LINUX_PC

    @property
    def ftdi_ft232h(self) -> bool:
        """Check whether the current board is an FTDI FT232H."""
        return self.id == boards.FTDI_FT232H

    @property
    def ftdi_ft2232h(self) -> bool:
        """Check whether the current board is an FTDI FT2232H."""
        return self.id == boards.FTDI_FT2232H

    @property
    def excamera_spidriver(self) -> bool:
        """Check whether the current board is an Excamera SPIDriver."""
        return self.id == boards.EXCAMERA_SPIDRIVER

    @property
    def ftdi_ft4232h(self) -> bool:
        """Check whether the current board is an FTDI FT4232H."""
        return self.id == boards.FTDI_FT4232H

    @property
    def microchip_mcp2221(self) -> bool:
        """Check whether the current board is a Microchip MCP2221."""
        return self.id == boards.MICROCHIP_MCP2221

    @property
    def os_agnostic_board(self) -> bool:
        """Check whether the current board is an OS agnostic special case."""
        return self.id == boards.OS_AGNOSTIC_BOARD

    @property
    def pico_u2if(self) -> bool:
        """Check whether the current board is a RPi Pico w/ u2if."""
        return self.id == boards.PICO_U2IF

    @property
    def feather_u2if(self) -> bool:
        """Check whether the current board is a Feather RP2040 w/ u2if."""
        return self.id == boards.FEATHER_U2IF

    @property
    def feather_can_u2if(self) -> bool:
        """Check whether the current board is a Feather CAN Bus RP2040 w/ u2if."""
        return self.id == boards.FEATHER_CAN_U2IF

    @property
    def feather_epd_u2if(self) -> bool:
        """Check whether the current board is a Feather ThinkInk RP2040 w/ u2if."""
        return self.id == boards.FEATHER_EPD_U2IF

    @property
    def feather_rfm_u2if(self) -> bool:
        """Check whether the current board is a Feather RFM RP2040 w/ u2if."""
        return self.id == boards.FEATHER_RFM_U2IF

    @property
    def itsybitsy_u2if(self) -> bool:
        """Check whether the current board is a Itsy Bitsy w/ u2if."""
        return self.id == boards.ITSYBITSY_U2IF

    @property
    def macropad_u2if(self) -> bool:
        """Check whether the current board is a MacroPad w/ u2if."""
        return self.id == boards.MACROPAD_U2IF

    @property
    def qtpy_u2if(self) -> bool:
        """Check whether the current board is a QT Py w/ u2if."""
        return self.id == boards.QTPY_U2IF

    @property
    def qt2040_trinkey_u2if(self) -> bool:
        """Check whether the current board is a QT Py w/ u2if."""
        return self.id == boards.QT2040_TRINKEY_U2IF

    @property
    def kb2040_u2if(self) -> bool:
        """Check whether the current board is a KB2040 w/ u2if."""
        return self.id == boards.KB2040_U2IF

    @property
    def rp2040_one_u2if(self) -> bool:
        """Check whether the current board is an RP2040 One w/ u2if."""
        return self.id == boards.RP2040_ONE_U2IF

    @property
    def radxa_x4_u2if(self) -> bool:
        """Check whether the current board is an RP2040 One w/ u2if."""
        return self.id == boards.RADXA_X4_U2IF

    @property
    def binho_nova(self) -> bool:
        """Check whether the current board is an BINHO NOVA."""
        return self.id == boards.BINHO_NOVA

    @property
    def greatfet_one(self) -> bool:
        """Check whether the current board is a GreatFET One."""
        return self.id == boards.GREATFET_ONE

    def __getattr__(self, attr: str) -> bool:
        """
        Detect whether the given attribute is the currently-detected board.  See list
        of constants at the top of this module for available options.
        """
        if self.id == attr:
            return True
        return False



#!/usr/bin/env python3

# SPDX-FileCopyrightText: 2021 Melissa LeBlanc-Williams for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""
`bin.detect`
================================================================================

Board detection and determination script

* Author(s): Melissa LeBlanc-Williams

Implementation Notes
--------------------

**Software and Dependencies:**

* Linux and Python 3.7 or Higher

"""

import adafruit_platformdetect

detector = adafruit_platformdetect.Detector()

print("Board Detection Test")
print()
print("Check that the Chip and Board IDs match your board and that this it is")
print("correctly detecting whether or not it is a Linux board.")
print()
print("Chip id: ", detector.chip.id)
print("Board id: ", detector.board.id)
print()
print("Linux Detection")
print("---------------")
print("Is this an embedded Linux system?", detector.board.any_embedded_linux)
print()
print("Raspberry Pi Boards")
print("-------------------")
if detector.board.any_raspberry_pi:
    print("Raspberry Pi detected.")
print("Is this a Pi 3B+?", detector.board.RASPBERRY_PI_3B_PLUS)
print("Is this a Pi 4B?", detector.board.RASPBERRY_PI_4B)
print("Is this a 40-pin Raspberry Pi?", detector.board.any_raspberry_pi_40_pin)
print("Is this a Raspberry Pi Compute Module?", detector.board.any_raspberry_pi_cm)
print()

print("Other Boards")
print("-------------------")
print(
    "Is this a Siemens Simatic IOT2000 Gateway?",
    detector.board.any_siemens_simatic_iot2000,
)
print("Is this a 96boards board?", detector.board.any_96boards)
print("Is this a BeagleBone board?", detector.board.any_beaglebone)
print("Is this a Giant board?", detector.board.any_giant_board)
print("Is this a Coral Dev board?", detector.board.any_coral_board)
print("Is this a MaaXBoard?", detector.board.any_maaxboard)
print("Is this a SiFive board? ", detector.board.any_sifive_board)
print("Is this a PYNQ board?", detector.board.any_pynq_board)
print("Is this a Rock Pi board?", detector.board.any_rock_pi_board)
print("Is this a NanoPi board?", detector.board.any_nanopi)
print("Is this a Khadas VIM3 board?", detector.board.khadas_vim3_40_pin)
print("Is this a Clockwork Pi board?", detector.board.any_clockwork_pi_board)
print("Is this a Seeed Board?", detector.board.any_seeed_board)
print("Is this a UDOO board?", detector.board.any_udoo_board)
print("Is this an ASUS Tinker board?", detector.board.any_asus_tinker_board)
print("Is this an STM32MP1 board?", detector.board.any_stm32mp1)
print("Is this a MilkV board?", detector.board.any_milkv_board)
print("Is this a Luckfox Pico board?", detector.board.any_luckfox_pico_board)
print("Is this a generic Linux PC?", detector.board.generic_linux)
print(
    "Is this an OS environment variable special case?", detector.board.os_environ_board
)

if detector.board.any_bananapi:
    print("Bananapi board detected.")

if detector.board.any_jetson_board:
    print("Jetson platform detected.")

if detector.board.any_tisk_board:
    print("TI platform detected.")

if detector.board.any_pynq_board:
    print("PYNQ platform detected.")

if detector.board.any_orange_pi:
    print("Orange Pi detected.")

if detector.board.any_lemaker:
    print("LeMaker board detected.")

if detector.board.any_odroid_40_pin:
    print("Odroid detected.")

if detector.board.any_onion_omega_board:
    print("Onion Omega detected.")

if detector.board.any_pine64_board:
    print("Pine64 device detected.")

if detector.board.any_rock_pi_board:
    print("Rock Pi device detected.")

if detector.board.any_clockwork_pi_board:
    print("Clockwork Pi device detected.")

if detector.board.any_asus_tinker_board:
    print("ASUS Tinker Board device detected.")

if detector.board.any_coral_board:
    print("Coral device detected.")

if detector.board.any_lubancat:
    print("LubanCat detected.")

if detector.board.any_siemens_simatic_iot2000:
    print("Siemens Simatic IOT2000 Gateway detected.")

if detector.board.any_nxp_navq_board:
    print("NXP NavQ board detected.")

if detector.board.any_walnutpi:
    print("Walnut Pi detected.")

if detector.board.any_horizon_board:
    print("Horizon detected.")
